

import React from 'react';
import { ElementInfo } from './types';
import { ViewpointCamInfo } from '.';
import { Actions, ApiConfig } from '@crystaldesign/diva-core';
import { HQS_Transform } from './parser/types';
import { RTVAnalyzeData } from './store/types';
export * from './parser/types';
export interface FreePlacesOnGrids {
    accessoire3DName: string;
    articleCodex: string;
    basketId: string;
    plannedOptions: {
        [codex: string]: string;
    };
    elementId?: string;
    grids: {
        [gridName: string]: {
            freeCells: number[];
            idx: number;
        };
    };
}
export interface PlannedPlacesOnGrids {
    shelf3DName: string;
    elementId?: string;
    basketId: string;
    catalogCodex: string;
    grids: {
        [gridName: string]: {
            accessories: ShelfAccessories[];
            idx: number;
        };
    };
    iln: string;
    plannedOptions: {
        [codex: string]: string;
    };
}
export interface ShelfAccessories {
    accessorie3DName: string;
    articleCodex: string;
    basketId: string;
    index: number;
    plannedOptions: {
        [key: string]: string;
    };
    noDelete: boolean;
    noMove: boolean;
}
export type TabGroupTypes = 'PLANNER' | 'ACC' | 'ACC_PLANNER' | 'OPTION' | 'SUMMARY' | 'STATICROOMLIST' | 'SHELFPLANNER' | 'DOORPLANNER' | 'PRODUCTS' | 'PROMOTED';
export interface ViewHandler {
    rtvAnalyzeData?: RTVAnalyzeData[];
    settingsState: {
        freePlacesOnGrids?: FreePlacesOnGrids[];
    };
    paletteViewHandler: {
        addAccessorieOnShelfPlannerView: any;
        deleteAccessorieOnShelfPlannerView: any;
        updateFreePlacesOnGrids: any;
        selectShelfAccessorie: (articleCodex?: string, basketId?: string) => void;
    };
    viewPlannerHandler: {
        onElementDeleted: (setId: string, elementId: number) => void;
        onElementCopy(setId: string, elementId: number, copyDir: 'LEFT' | 'RIGHT' | 'TOP' | 'STD'): void;
    };
    divaWebPlanner: {
        getFreeToMovePlacesOnGrids(gridName: string, basketId: string): FreePlacesOnGrids[] | undefined;
        moveShelfItemToGrid(accessoireBasketId: string, parentBasketId: string, gridName: string, cellIndex: number): Promise<void>;
        getEnableUnityRtvKombi: () => boolean;
    };
    tabgroupTypeActive: (type: TabGroupTypes) => boolean;
    tabGroupState: any;
}
export interface UIConfig {
    templateConfig: 'standard' | 'gold' | 'hidden';
    posNumIcon: 'TOP_LEFT_BACK';
    posTrashIcon: 'TOP_RIGHT_BACK' | 'POSNUM_TOP';
    hideUiIcons: boolean;
}
export interface Props {
    renderjob: string;
    actions: Actions;
    apiConfig: ApiConfig;
    callbacks: {
        onInitialized?: () => void;
        viewpointCreated?: (name: string, global: boolean, position: HQS_Transform, rotation: HQS_Transform) => void;
        setGlb?: (glbUrl: any, globBlob?: Blob) => any;
        onElementSelected?: (setId: string, elementId: number) => void;
        onMissingGeo?: () => void;
        requestNewOverlayImage?: (viewpoint: ViewpointCamInfo, focus: {
            adjustZoomInUnity: boolean;
            onlyAdjustZoomBBChanged: boolean;
            rotationCenter: {
                x: number;
                y: number;
                z: number;
            };
            setId?: string;
            elementId?: number;
        }) => void;
        updateCameraInformation?: (cam: ViewpointCamInfo) => void;
    };
    renderInBackground: boolean;
    uiConfig?: UIConfig;
    overlayImage?: {
        base64: string;
        isStaticBg: boolean;
        isStart: boolean;
    };
    viewpoint?: ViewpointCamInfo;
    isMobile?: boolean;
    elementsInfo?: ElementInfo[];
    resolution?: {
        x: number;
        y: number;
    };
    inBackground?: boolean;
    viewHandler?: ViewHandler;
    freePlacesOnGrids?: FreePlacesOnGrids[];
    plannedPlacesOnGrids?: PlannedPlacesOnGrids[];
    jwt?: string;
}
declare const RealTimeRenderer: React.MemoExoticComponent<(props: Props) => React.JSX.Element>;
export default RealTimeRenderer;
//# sourceMappingURL=index.d.ts.map
  