import { Scene } from '@babylonjs/core/scene';
import { Vector3 } from '@babylonjs/core/Maths/math.vector';
import { TransformNode } from '@babylonjs/core/Meshes/transformNode';
import { HQRenderScript, HQS_Node, ViewpointCamInfo } from '../parser/types';
import { ArcRotateCamera } from '@babylonjs/core/Cameras/arcRotateCamera';
import { GLTFData } from '@babylonjs/serializers';
import { SSAO2RenderingPipeline, DefaultRenderingPipeline } from '@babylonjs/core/PostProcesses';
import { Node } from '@babylonjs/core/node';
import { Cache } from './../types';
import { Light } from '@babylonjs/core/Lights/light';
import { UtilStore } from './UtilStore';
import { MaterialCache } from './types';
import { ApiConfig } from '@crystaldesign/diva-core';
export declare class SceneStore {
    private _hqRenderScript;
    private _previousHQRenderScript;
    private _scene;
    private _cams;
    private _geos;
    private _sceneConstruct;
    private _hasRendered;
    private _hasPlanned;
    private _modelIteration;
    private _utilStore;
    private _cache;
    private _ssao;
    private _renderPipeline;
    private _isInitializing;
    private _optimizer;
    private _apiConfig;
    private _jwt;
    private _onMissingGeo;
    private _cancelSceneExport;
    private _materialCache;
    private _renderControlLoop;
    private _doRenderControlLoop;
    private _cameraTargetPosition;
    private _targetCameraPosition;
    private _selectedElements?;
    private _focusedElement?;
    private _isControlledViewpoint;
    private _renderLoopTimeoutId;
    light: Light | undefined;
    changedElements: {
        parent: HQS_Node | undefined;
        updatedElements: HQS_Node[] | undefined;
        deletedElements: HQS_Node[] | undefined;
    } | undefined;
    updateCameraInformation?: (cam: ViewpointCamInfo) => void;
    constructor(scene: Scene, hqRenderScript: string, utilStore: UtilStore, apiConfig: ApiConfig, jwt?: string, onMissingGeo?: () => void, updateCameraInformation?: (cam: ViewpointCamInfo) => void);
    get materialCache(): MaterialCache[];
    get modelIteration(): number;
    get jwt(): string | undefined;
    get apiConfig(): ApiConfig;
    get scene(): Scene;
    get sets(): import("./types").Set[] | undefined;
    get geos(): TransformNode[];
    get cache(): Cache[];
    get doRenderControlLoop(): boolean;
    get selectedElements(): string[];
    get focusedElement(): any;
    get isControlledViewpoint(): boolean;
    set focusedElement(val: any);
    set isControlledViewpoint(value: boolean);
    set selectedElements(element: string[]);
    set doRenderControlLoop(doRenderControlLoop: boolean);
    get controlRenderLoop(): () => void;
    set controlRenderLoop(renderLoop: () => void);
    set cache(ch: Cache[]);
    get hqRenderScript(): HQRenderScript;
    get root(): {
        hqs: HQS_Node;
        bbn: TransformNode;
        sets: import("./types").Set[];
    } | undefined;
    get mainElements(): import("./types").Element[];
    get elements(): import("./types").Element[];
    get cameraTargetPosition(): Vector3;
    get targetCameraPosition(): Vector3;
    get isInitializing(): boolean;
    set cameraTargetPosition(pos: Vector3);
    set targetCameraPosition(pos: Vector3);
    set isInitializing(isInit: boolean);
    enableSSAO(enable: boolean): void;
    getElementByName(name: string): import("./types").Element | undefined;
    getElementNameById(id: number): string | undefined;
    get hasRendered(): boolean;
    get hasPlanned(): boolean;
    get cams(): ArcRotateCamera[];
    get previousHQRenderScript(): HQRenderScript | undefined;
    get activeCamera(): import("@babylonjs/core").Camera;
    get meshes(): import("@babylonjs/core").AbstractMesh[];
    get ssao(): SSAO2RenderingPipeline;
    get renderPipeline(): DefaultRenderingPipeline;
    set hqRenderScript(hqRenderScript: HQRenderScript);
    set hasRendered(value: boolean);
    set hasPlanned(value: boolean);
    set renderPipeline(renderPipeline: DefaultRenderingPipeline);
    set ssao(ssao: SSAO2RenderingPipeline);
    private renderLoop;
    runRenderLoop(): void;
    runRenderLoopIndefinitely(): void;
    runRenderLoopForTime(ms: number): void;
    stopRenderLoop(): void;
    private setResolution;
    checkMaterialCache(): void;
    addMaterialToCache(materialCache: MaterialCache): void;
    updateModelIteration(): void;
    init(diva3durl: string, gameCanvas: HTMLCanvasElement | null, viewpoint?: ViewpointCamInfo, resolution?: {
        x: number;
        y: number;
    }): void;
    setRoot(bbn: TransformNode, hqs: HQS_Node): void;
    addSet(bbn: TransformNode, hqs: HQS_Node): void;
    addElement(bbn: TransformNode, hqs: HQS_Node): void;
    removeElement(hqs: HQS_Node): void;
    private shouldExport;
    onMissingGeo(): void;
    exportScene(): Promise<GLTFData | undefined>;
    optimizeScene(): void;
    setCameraTarget(): void;
    getId(ob: Node): string;
    focusElement(root?: TransformNode): void;
    getMaxCamPosition(): Vector3;
}
//# sourceMappingURL=SceneStore.d.ts.map