import { useRef, useEffect, memo } from 'react';
import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import { Color4, Color3 } from '@babylonjs/core/Maths/math.color';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { Tags } from '@babylonjs/core/Misc/tags';
import { Vector3, Matrix, Vector2 } from '@babylonjs/core/Maths/math.vector';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { MeshBuilder } from '@babylonjs/core/Meshes/meshBuilder';
import { ActionManager } from '@babylonjs/core/Actions/actionManager';
import { ExecuteCodeAction } from '@babylonjs/core/Actions/directActions';
import { PBRMaterial } from '@babylonjs/core/Materials/PBR/pbrMaterial';
import '@babylonjs/core/Rendering/edgesRenderer';
import { GLTF2Export } from '@babylonjs/serializers';
import '@babylonjs/core/Helpers/sceneHelpers';
import { CubeTexture } from '@babylonjs/core/Materials/Textures/cubeTexture';
import { SSAO2RenderingPipeline } from '@babylonjs/core/PostProcesses/RenderPipeline/Pipelines/ssao2RenderingPipeline';
import '@babylonjs/core/Rendering/geometryBufferRendererSceneComponent';
import '@babylonjs/core/Rendering/prePassRendererSceneComponent';
import { UniversalCamera } from '@babylonjs/core/Cameras/universalCamera';
import { PBRMetallicRoughnessMaterial } from '@babylonjs/core/Materials/PBR/pbrMetallicRoughnessMaterial';
import { DirectionalLight } from '@babylonjs/core/Lights/directionalLight';
import { Tools, Observable, WebRequest } from '@babylonjs/core/Misc';
import { SceneOptimizerOptions, ShadowsOptimization, RenderTargetsOptimization, SceneOptimizer } from '@babylonjs/core/Misc/sceneOptimizer';
import { getLogger, DivaError } from '@crystaldesign/diva-core';
import { TransformNode } from '@babylonjs/core/Meshes/transformNode';
import { AdvancedDynamicTexture } from '@babylonjs/gui/2D/advancedDynamicTexture';
import { Button } from '@babylonjs/gui/2D/controls/button';
import { Ellipse } from '@babylonjs/gui/2D/controls/ellipse';
import { Effect } from '@babylonjs/core/Materials/effect';
import { ShaderMaterial } from '@babylonjs/core/Materials/shaderMaterial';
import '@babylonjs/core/Engines/WebGPU/Extensions/engine.dynamicTexture';
import '@babylonjs/core/Engines/WebGPU/Extensions/engine.multiRender';
import '@babylonjs/core/Engines/WebGPU/Extensions/engine.renderTarget';
import '@babylonjs/core/Engines/WebGPU/Extensions/engine.renderTargetTexture';
import { Rectangle } from '@babylonjs/gui/2D/controls/rectangle';
import { TextBlock } from '@babylonjs/gui/2D/controls/textBlock';
import { Mesh } from '@babylonjs/core/Meshes/mesh';
import { Axis } from '@babylonjs/core/Maths/math.axis';
import { Texture } from '@babylonjs/core/Materials/Textures/texture';
import { Constants } from '@babylonjs/core/Engines/constants';
import { HighlightLayer } from '@babylonjs/core/Layers';
import { Matrix as Matrix$1, Vector3 as Vector3$1 } from '@babylonjs/core/Maths/math';
import { EngineFactory } from '@babylonjs/core/Engines/engineFactory';
import { Scene } from '@babylonjs/core/scene';
import { DracoCompression } from '@babylonjs/core/Meshes/Compression/dracoCompression';
import { SceneLoader } from '@babylonjs/core/Loading/sceneLoader';
import '@babylonjs/loaders/glTF/2.0/';
import { jsx } from 'react/jsx-runtime';

(function() {
    const env = {"STAGE":"production"};
    try {
        if (process) {
            process.env = Object.assign({}, process.env);
            Object.assign(process.env, env);
            return;
        }
    } catch (e) {} // avoid ReferenceError: process is not defined
    globalThis.process = { env:env };
})();

function GetCameraControls(camera) {
  var sceneStore = useSceneStoreContext();
  var uistore = useUIStoreContext();
  sceneStore.controlRenderLoop = renderLoop;
  var maxCamPosition = sceneStore.getMaxCamPosition();
  var previousTouch;
  var isZooming = false;
  var initDistance = 0;
  function renderLoop() {
    if (!sceneStore.doRenderControlLoop || sceneStore.isInitializing || uistore.isStaticBg) return;
    uistore.onMove();
    var stopRender = true;
    var delta = sceneStore.scene.getEngine().getDeltaTime();
    var deltaCamPos = sceneStore.targetCameraPosition.subtract(camera.position).multiplyByFloats(delta / 100, delta / 100, delta / 100);
    var deltaTarget = sceneStore.cameraTargetPosition.subtract(camera.target).multiplyByFloats(delta / 100, delta / 100, delta / 100);
    if (Math.abs(deltaCamPos.x) + Math.abs(deltaCamPos.y) + Math.abs(deltaCamPos.z) > 0.0001) {
      camera.position = camera.position.addInPlaceFromFloats(deltaCamPos.x, deltaCamPos.y, deltaCamPos.z);
      camera.setTarget(sceneStore.cameraTargetPosition);
      stopRender = false;
    }
    if (Math.abs(deltaTarget.x) + Math.abs(deltaTarget.y) + Math.abs(deltaTarget.z) > 0.0001) {
      camera.setTarget(camera.target.addInPlaceFromFloats(deltaTarget.x, deltaTarget.y, deltaTarget.z));
      stopRender = false;
    }
    var cam = {
      horiFov: camera.fov * 180 / Math.PI,
      lensShiftX: 0,
      lensShiftY: 0,
      name: camera.name,
      pos: {
        x: camera.position.x,
        y: camera.position.y,
        z: camera.position.z
      },
      rot: {
        x: camera.rotation.x * 180 / Math.PI,
        y: camera.rotation.y * 180 / Math.PI,
        z: camera.rotation.z * 180 / Math.PI
      },
      targetPos: {
        x: camera.target.x,
        y: camera.target.y,
        z: camera.target.z
      },
      vertFov: camera.fov * 180 / Math.PI
    };
    uistore.requestNewOverlayImage(cam, sceneStore.focusedElement, sceneStore.targetCameraPosition, sceneStore.updateCameraInformation);
    if (stopRender) {
      sceneStore.doRenderControlLoop = false;
    }
  }
  function moveTarget(deltaX, deltaY) {
    sceneStore.isControlledViewpoint = false;
    var localRight = Vector3.TransformNormal(Vector3.Right(), camera.getWorldMatrix());
    var localUp = Vector3.TransformNormal(Vector3.Up(), camera.getWorldMatrix());
    localRight = localRight.normalize();
    localUp = localUp.normalize();
    sceneStore.targetCameraPosition = sceneStore.targetCameraPosition.add(localUp.scale(deltaY));
    sceneStore.targetCameraPosition = sceneStore.targetCameraPosition.add(localRight.scale(-deltaX));
    var newCalculatedTarget = sceneStore.targetCameraPosition.add(camera.getForwardRay().direction.scale(Vector3.Distance(sceneStore.targetCameraPosition, sceneStore.cameraTargetPosition)));
    sceneStore.cameraTargetPosition = newCalculatedTarget;
    if (newCalculatedTarget.x > maxCamPosition.x) {
      sceneStore.targetCameraPosition.x = camera.position.x;
      sceneStore.cameraTargetPosition.x = maxCamPosition.x;
    }
    if (newCalculatedTarget.x < -maxCamPosition.x) {
      sceneStore.targetCameraPosition.x = camera.position.x;
      sceneStore.cameraTargetPosition.x = -maxCamPosition.x;
    }
    if (newCalculatedTarget.z > maxCamPosition.z) {
      sceneStore.targetCameraPosition.z = camera.position.z;
      sceneStore.cameraTargetPosition.z = maxCamPosition.z;
    }
    if (newCalculatedTarget.z < -maxCamPosition.z) {
      sceneStore.targetCameraPosition.z = camera.position.z;
      sceneStore.cameraTargetPosition.z = -maxCamPosition.z;
    }
  }
  function moveCameraAwayFromTarget(distance) {
    var directionVector = sceneStore.targetCameraPosition.subtract(camera.target);
    directionVector.normalize();
    var previousDistToTarget = Vector3.Distance(sceneStore.cameraTargetPosition, sceneStore.targetCameraPosition);
    var newPosition = sceneStore.targetCameraPosition.add(directionVector.scale(distance * previousDistToTarget));
    var distToTarget = Vector3.Distance(sceneStore.cameraTargetPosition, newPosition);
    if (distToTarget < 0.1) return;
    if (distToTarget > 75) return;
    sceneStore.isControlledViewpoint = false;
    sceneStore.targetCameraPosition = newPosition;
  }
  function onRotate(deltaX, deltaY) {
    function rotateUniversalCamera(deltaX, deltaY) {
      function calculateAngles() {
        var dx = sceneStore.targetCameraPosition.x - sceneStore.cameraTargetPosition.x;
        var dy = sceneStore.targetCameraPosition.y - sceneStore.cameraTargetPosition.y;
        var dz = sceneStore.targetCameraPosition.z - sceneStore.cameraTargetPosition.z;
        var distance = Math.sqrt(dx * dx + dy * dy + dz * dz);
        var alpha = Math.atan2(dz, dx); // angle around the y-axis
        var beta = Math.acos(dy / distance); // elevation angle

        return {
          alpha: alpha,
          beta: beta,
          distance: distance
        };
      }
      function clamp(value, min, max) {
        return Math.max(min, Math.min(max, value));
      }
      var _calculateAngles = calculateAngles(),
        alpha = _calculateAngles.alpha,
        beta = _calculateAngles.beta,
        distance = _calculateAngles.distance;
      alpha = alpha + deltaX * -0.003;
      beta = clamp(beta + deltaY * -0.003, 0.1, Math.PI / 2);
      var x = sceneStore.cameraTargetPosition.x + distance * Math.sin(beta) * Math.cos(alpha);
      var y = sceneStore.cameraTargetPosition.y + distance * Math.cos(beta);
      var z = sceneStore.cameraTargetPosition.z + distance * Math.sin(beta) * Math.sin(alpha);
      sceneStore.targetCameraPosition = new Vector3(x, y, z);
    }
    rotateUniversalCamera(deltaX, deltaY);
    if (!sceneStore.doRenderControlLoop) sceneStore.runRenderLoopIndefinitely();
    sceneStore.doRenderControlLoop = true;
  }
  function onRotateMouse(event) {
    if (previousTouch != undefined) return;
    var deltaX = event.movementX || 0;
    var deltaY = event.movementY || 0;
    onRotate(deltaX, deltaY);
  }
  function onMouseDown(ev) {
    if (isZooming) return;
    var element = camera.getEngine().getRenderingCanvas();
    if (ev.button == 0) {
      element === null || element === void 0 || element.addEventListener('pointermove', onRotateMouse, false);
    }
    if (ev.button == 2 || ev.button == 1) {
      maxCamPosition = sceneStore.getMaxCamPosition();
      element === null || element === void 0 || element.addEventListener('pointermove', onMouseMoveTarget, false);
    }
  }
  function onMouseUp(ev) {
    var element = camera.getEngine().getRenderingCanvas();
    element === null || element === void 0 || element.removeEventListener('pointermove', onRotateMouse, false);
    element === null || element === void 0 || element.removeEventListener('pointermove', onMouseMoveTarget, false);
  }
  function onMouseMoveTarget(event) {
    var deltaX = event.movementX || 0;
    var deltaY = event.movementY || 0;
    moveTarget(deltaX * 0.002, deltaY * 0.002);
    if (!sceneStore.doRenderControlLoop) sceneStore.runRenderLoopIndefinitely();
    sceneStore.doRenderControlLoop = true;
  }
  var onTouchStart = function onTouchStart(ev) {
    if (ev.touches.length != 2) return;
    isZooming = true;
    maxCamPosition = sceneStore.getMaxCamPosition();
    initDistance = Math.hypot(ev.touches[0].pageX - ev.touches[1].pageX, ev.touches[0].pageY - ev.touches[1].pageY);
  };
  var onTouchEnd = function onTouchEnd() {
    isZooming = false;
    previousTouch = undefined;
  };
  var onTouchMove = function onTouchMove(ev) {
    ev.preventDefault();
    if (ev.touches.length == 1 && previousTouch) {
      onRotate(ev.touches[0].clientX - previousTouch.touches[0].clientX, ev.touches[0].clientY - previousTouch.touches[0].clientY);
    } else if (ev.touches.length == 2 && previousTouch && previousTouch.touches.length == 2) {
      //move target
      var diffX = ev.touches[0].pageX + ev.touches[1].pageX - (previousTouch.touches[0].pageX + previousTouch.touches[1].pageX);
      var diffY = ev.touches[0].pageY + ev.touches[1].pageY - (previousTouch.touches[0].pageY + previousTouch.touches[1].pageY);
      moveTarget(diffX * 0.002, diffY * 0.002);
      // zoom
      var dist = Math.hypot(ev.touches[0].pageX - ev.touches[1].pageX, ev.touches[0].pageY - ev.touches[1].pageY);
      var distChange = dist - initDistance;
      moveCameraAwayFromTarget(-distChange * 0.01);
      if (!sceneStore.doRenderControlLoop) sceneStore.runRenderLoopIndefinitely();
      sceneStore.doRenderControlLoop = true;
      initDistance = dist;
    }
    previousTouch = ev;
  };
  function onMouseScroll(ev) {
    ev.preventDefault();
    if (isZooming) return;
    var add = 0.1;
    if (ev.ctrlKey) {
      add = 0.06;
    }
    var value = ev.deltaY > 0 ? add : -add;
    moveCameraAwayFromTarget(value * 2);
    if (!sceneStore.doRenderControlLoop) sceneStore.runRenderLoopIndefinitely();
    sceneStore.doRenderControlLoop = true;
  }
  function onDoubleClick() {}
  function attachControl(noPreventDefault) {
    var element = camera.getEngine().getRenderingCanvas();
    element === null || element === void 0 || element.addEventListener('touchstart', onTouchStart, false);
    element === null || element === void 0 || element.addEventListener('touchmove', onTouchMove, false);
    element === null || element === void 0 || element.addEventListener('pointerdown', onMouseDown, false);
    element === null || element === void 0 || element.addEventListener('pointerup', onMouseUp, false);
    element === null || element === void 0 || element.addEventListener('touchend', onTouchEnd, false);
    element === null || element === void 0 || element.addEventListener('wheel', onMouseScroll, false);
    element === null || element === void 0 || element.addEventListener('dblclick', onDoubleClick, false);
  }
  function detachControl() {
    var element = camera.getEngine().getRenderingCanvas();
    element === null || element === void 0 || element.removeEventListener('pointerdown', onMouseDown, false);
    element === null || element === void 0 || element.removeEventListener('pointerup', onMouseUp, false);
    element === null || element === void 0 || element.removeEventListener('wheel', onMouseScroll, false);
    element === null || element === void 0 || element.removeEventListener('touchstart', onTouchStart, false);
    element === null || element === void 0 || element.removeEventListener('touchend', onTouchEnd, false);
    element === null || element === void 0 || element.removeEventListener('touchmove', onTouchMove, false);
    element === null || element === void 0 || element.removeEventListener('pointermove', onRotateMouse, false);
    element === null || element === void 0 || element.removeEventListener('pointermove', onMouseMoveTarget, false);
  }
  var CameraControls = {
    camera: camera,
    onMouseDown: onMouseDown,
    onMouseUp: onMouseUp,
    onMouseMoveTarget: onMouseMoveTarget,
    onMouseScroll: onMouseScroll,
    getClassName: function getClassName() {
      return 'CameraControls';
    },
    getSimpleName: function getSimpleName() {
      return 'mouse';
    },
    attachControl: attachControl,
    detachControl: detachControl,
    checkInputs: function checkInputs() {}
  };
  return CameraControls;
}
function getGridControls(scene, element, selected, elements, selectMesh) {
  var gridStore = useGridStoreContext();
  var utilStore = useUtilStoreContext();
  var _curGrid = selected;
  var onGridMove = function onGridMove(ev) {
    var _scene$activeCamera, _scene$getMeshById, _elements$find$bbn$na, _elements$find, _Tags$GetTags;
    (_scene$activeCamera = scene.activeCamera) === null || _scene$activeCamera === void 0 || _scene$activeCamera.detachControl();
    var metadata = (_scene$getMeshById = scene.getMeshById(selected.id)) === null || _scene$getMeshById === void 0 ? void 0 : _scene$getMeshById.metadata;
    if (!metadata) return;
    var _ref = gridStore.getDataFromGridName(selected.name, metadata.elementId),
      startShelfIdx = _ref.shelfIdx,
      startGridIdx = _ref.gridIdx;
    var actualHQRObj = scene.getTransformNodeByName((_elements$find$bbn$na = (_elements$find = elements.find(function (el) {
      return el === null || el === void 0 ? void 0 : el.bbn.name.endsWith(metadata.elementId + '.' + startGridIdx + '.' + startShelfIdx);
    })) === null || _elements$find === void 0 ? void 0 : _elements$find.bbn.name) !== null && _elements$find$bbn$na !== void 0 ? _elements$find$bbn$na : '');
    if (!actualHQRObj) return;
    var mouseX = ev.clientX;
    var mouseY = ev.clientY;

    // Convert mouse coordinates to 3D world coordinates
    var rect = scene.getEngine().getRenderingCanvas().getBoundingClientRect();
    var canvasX = mouseX - rect.left;
    var canvasY = mouseY - rect.top;
    var pickResult = scene.pick(canvasX, canvasY);
    if (!pickResult.pickedMesh || !((_Tags$GetTags = Tags.GetTags(pickResult.pickedMesh)) !== null && _Tags$GetTags !== void 0 && _Tags$GetTags.includes('free')) && pickResult.pickedMesh.name != selected.name) return;
    var closestGrid = pickResult.pickedMesh;
    if (closestGrid) {
      scene.getMeshesByTags('free').forEach(function (mesh) {
        return mesh.material.alpha = 0.2;
      });
      actualHQRObj.setAbsolutePosition(new Vector3(closestGrid.absolutePosition.x, closestGrid.absolutePosition.y, closestGrid.absolutePosition.z));
      actualHQRObj.position = actualHQRObj.position.addInPlace(closestGrid.metadata.geoPos);
      actualHQRObj.rotation = new Vector3(closestGrid.rotation.x, closestGrid.rotation.y, closestGrid.rotation.z);
      var size = closestGrid.getBoundingInfo().maximum.subtract(closestGrid.getBoundingInfo().minimum);
      utilStore.moveObjectInDirection(actualHQRObj, Vector3.Right(), -size.x / 2 + closestGrid.metadata.rulePos.x);
      utilStore.moveObjectInDirection(actualHQRObj, Vector3.Up(), -size.y / 2 + closestGrid.metadata.rulePos.y);
      utilStore.moveObjectInDirection(actualHQRObj, Vector3.Forward(), size.z / 2 + closestGrid.metadata.rulePos.z);
      _curGrid = closestGrid;
    }
  };
  var register = function register(basketId, gridIdx, shelfIdx, accessoireBasketId) {
    var _onGridMoveOut = function onGridMoveOut() {
      var _curGrid2, _curGrid3, _scene$activeCamera2;
      element === null || element === void 0 || element.removeEventListener('pointermove', onGridMove, false);
      element === null || element === void 0 || element.removeEventListener('pointerup', _onGridMoveOut, false);
      _curGrid = scene.getMeshByName((_curGrid2 = _curGrid) === null || _curGrid2 === void 0 ? void 0 : _curGrid2.name);
      if (!_curGrid) return;
      var _ref2 = gridStore.getDataFromGridName((_curGrid3 = _curGrid) === null || _curGrid3 === void 0 ? void 0 : _curGrid3.name, _curGrid.metadata.elementId),
        curBasketId = _ref2.parentBasketId,
        curShelfIdx = _ref2.shelfIdx,
        curGridIdx = _ref2.gridIdx,
        gridName = _ref2.gridName;
      if (basketId === curBasketId && gridIdx === curGridIdx && shelfIdx === curShelfIdx) {
        gridStore.rerenderGrids();
      } else {
        var _utilStore$viewHandle;
        (_utilStore$viewHandle = utilStore.viewHandler) === null || _utilStore$viewHandle === void 0 || _utilStore$viewHandle.divaWebPlanner.moveShelfItemToGrid(accessoireBasketId, curBasketId, gridName, curShelfIdx);
      }
      var tags = Tags.GetTags(_curGrid);
      selectMesh(_curGrid, curGridIdx, curShelfIdx, curBasketId, tags.includes('disableDelete'), tags.includes('disableMove'));
      (_scene$activeCamera2 = scene.activeCamera) === null || _scene$activeCamera2 === void 0 || _scene$activeCamera2.attachControl();
    };
    element === null || element === void 0 || element.addEventListener('pointermove', onGridMove, false);
    element === null || element === void 0 || element.addEventListener('pointerup', _onGridMoveOut, false);
  };
  return {
    register: register
  };
}

function _createForOfIteratorHelper$8(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$8(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$8(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$8(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$8(r, a) : void 0; } }
function _arrayLikeToArray$8(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function Grids () {
  var utilStore = useUtilStoreContext();
  var sceneStore = useSceneStoreContext();
  var gridStore = useGridStoreContext();
  var _plannedPlaceOnGrids = [];
  function deleteAllGrids() {
    sceneStore.scene.getMeshesByTags('grid').forEach(function (m) {
      return m.dispose();
    });
  }
  function setupPreviewGrids(allGrids, plannedPlacesOnGrids, freePlacesOnGrids) {
    deleteAllGrids();
    _plannedPlaceOnGrids = plannedPlacesOnGrids;
    if (gridStore.selectedGrid && (freePlacesOnGrids === null || freePlacesOnGrids === void 0 ? void 0 : freePlacesOnGrids[0]) != undefined && !Tags.GetTags(gridStore.selectedGrid).includes('ac:' + freePlacesOnGrids[0].articleCodex)) {
      gridStore.deselectGrids(false);
    }
    var _loop = function _loop() {
      var plannedPlaceOnGrid = plannedPlacesOnGrids === null || plannedPlacesOnGrids === void 0 ? void 0 : plannedPlacesOnGrids[idx];
      var freePlaceOnGrid = freePlacesOnGrids === null || freePlacesOnGrids === void 0 ? void 0 : freePlacesOnGrids[idx];
      if (freePlaceOnGrid) {
        var accessorie3DName = freePlaceOnGrid.accessoire3DName;
        var gridsForElement = allGrids.find(function (allGrid) {
          return allGrid.elementId == plannedPlaceOnGrid.elementId;
        });
        if (Object.values(freePlaceOnGrid.grids).find(function (g) {
          return g.freeCells.length > 0;
        })) {
          if (!gridsForElement) throw new Error('Could not find grids for element with id: ' + gridsForElement);
          var accessorie = gridsForElement.accessories.find(function (a) {
            return a.artNr == accessorie3DName;
          });
          if (!accessorie) throw new Error('Could not find accessorie with name: ' + accessorie3DName);
          var geo = accessorie.geo;
          var geoSize = new Vector3(geo.geoSize.x, geo.geoSize.y, geo.geoSize.z);
          var bboxSize = new Vector3(geo.geoBboxSize.x, geo.geoBboxSize.y, geo.geoBboxSize.z);
          var rulePosition = new Vector3(geo.rulePosition.x, geo.rulePosition.y, geo.rulePosition.z);
          var geoPosition = new Vector3(geo.geoPosition.x, geo.geoPosition.y, geo.geoPosition.z);
          var _loop2 = function _loop2() {
            var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
              gridName = _Object$entries$_i[0],
              freeGrid = _Object$entries$_i[1];
            var grid = gridsForElement.grids.find(function (grid) {
              return grid.gridName == gridName;
            });
            if (!grid) {
              throw new Error('Could not find grid with name: ' + gridName);
            }
            for (var shelfIdx = 0; shelfIdx < grid.count; shelfIdx++) {
              if (!freeGrid.freeCells.includes(shelfIdx)) continue;
              createGrid({
                grid: grid,
                bboxSize: bboxSize,
                geoSize: geoSize,
                rulePosition: rulePosition,
                geoPosition: geoPosition
              }, freePlaceOnGrid.elementId, shelfIdx, freeGrid.idx, true, false, false, freePlaceOnGrid.articleCodex);
            }
          };
          for (var _i = 0, _Object$entries = Object.entries(freePlaceOnGrid.grids); _i < _Object$entries.length; _i++) {
            _loop2();
          }
        }
      }
      if (plannedPlaceOnGrid) {
        var _loop3 = function _loop3() {
          var _Object$entries2$_i = _slicedToArray(_Object$entries2[_i2], 2),
            gridName = _Object$entries2$_i[0];
            _Object$entries2$_i[1];
          var _iterator = _createForOfIteratorHelper$8(plannedPlaceOnGrid.grids[gridName].accessories),
            _step;
          try {
            var _loop4 = function _loop4() {
              var _step$value = _step.value,
                accessorie3DName = _step$value.accessorie3DName,
                articleCodex = _step$value.articleCodex,
                noDelete = _step$value.noDelete,
                noMove = _step$value.noMove,
                index = _step$value.index;
              var gridsOfElement = allGrids.find(function (allGrid) {
                return allGrid.elementId == plannedPlaceOnGrid.elementId;
              });
              if (!gridsOfElement) throw new Error('could not find grids for element ' + plannedPlaceOnGrid.elementId);
              var grid = gridsOfElement === null || gridsOfElement === void 0 ? void 0 : gridsOfElement.grids.find(function (grid) {
                return grid.gridName == gridName;
              });
              if (!grid) throw new Error('could not find grid for gridname ' + gridName);
              var accessorie = gridsOfElement === null || gridsOfElement === void 0 ? void 0 : gridsOfElement.accessories.find(function (a) {
                return a.artNr == accessorie3DName;
              });
              var geo = accessorie.geo;
              var geoSize = new Vector3(geo.geoSize.x, geo.geoSize.y, geo.geoSize.z);
              var rulePosition = new Vector3(geo.rulePosition.x, geo.rulePosition.y, geo.rulePosition.z);
              var geoPosition = new Vector3(geo.geoPosition.x, geo.geoPosition.y, geo.geoPosition.z);
              createGrid({
                grid: grid,
                bboxSize: geoSize,
                geoSize: geoSize,
                rulePosition: rulePosition,
                geoPosition: geoPosition
              }, plannedPlaceOnGrid.elementId, index, plannedPlaceOnGrid.grids[grid.gridName].idx, false, noDelete, noMove, articleCodex);
            };
            for (_iterator.s(); !(_step = _iterator.n()).done;) {
              _loop4();
            }
          } catch (err) {
            _iterator.e(err);
          } finally {
            _iterator.f();
          }
        };
        for (var _i2 = 0, _Object$entries2 = Object.entries(plannedPlaceOnGrid.grids); _i2 < _Object$entries2.length; _i2++) {
          _loop3();
        }
      }
    };
    for (var idx = 0; idx < plannedPlacesOnGrids.length; idx++) {
      _loop();
    }
  }
  function createGrid(data, elementId, shelfIdx, gridIdx, isFree, noDelete, noMove, articleCodex) {
    var _sceneStore$elements, _sceneStore$scene$get;
    var grid = data.grid;
    var elementName = (_sceneStore$elements = sceneStore.elements) === null || _sceneStore$elements === void 0 || (_sceneStore$elements = _sceneStore$elements.find(function (el) {
      return el.bbn.name.endsWith(elementId);
    })) === null || _sceneStore$elements === void 0 || (_sceneStore$elements = _sceneStore$elements.bbn) === null || _sceneStore$elements === void 0 ? void 0 : _sceneStore$elements.name;
    if (!elementName) return;
    var element = sceneStore.scene.getTransformNodeByName(elementName);
    if (!element) return;
    var box = MeshBuilder.CreateBox(elementId + '.' + gridIdx + '.' + shelfIdx + '.' + grid.gridName, {
      width: data.bboxSize.x / 100,
      height: data.bboxSize.y / 100,
      depth: data.bboxSize.z / 100
    }, sceneStore.scene);
    box.parent = element;
    box.isPickable = true;
    box.position = new Vector3(-grid.originPosition.x / 100, grid.originPosition.y / 100, -grid.originPosition.z / 100);
    if (grid.rotation) box.rotation.y = grid.rotation * Math.PI / 180;
    box.metadata = {
      elementId: elementId,
      rulePos: {
        x: data.rulePosition.x / 100,
        y: data.rulePosition.y / 100,
        z: data.rulePosition.z / 100
      },
      geoPos: new Vector3(data.geoPosition.x / 100, data.geoPosition.y / 100, data.geoPosition.z / 100)
    };
    var bboxDiff = data.bboxSize.subtract(data.geoSize);
    utilStore.moveObjectInDirection(box, new Vector3(1, 0, 0), (shelfIdx * -grid.deltaGrid.x - data.geoPosition.x) / 100 + (data.geoSize.x + bboxDiff.x) / 200 - box.metadata.rulePos.x);
    utilStore.moveObjectInDirection(box, new Vector3(0, 1, 0), (shelfIdx * grid.deltaGrid.y + data.geoPosition.y) / 100 + (data.geoSize.y + bboxDiff.y) / 200 - box.metadata.rulePos.y);
    utilStore.moveObjectInDirection(box, new Vector3(0, 0, 1), (shelfIdx * grid.deltaGrid.z - data.geoPosition.z) / 100 - (data.geoSize.z + bboxDiff.z) / 200 - box.metadata.rulePos.z);
    box.material = (_sceneStore$scene$get = sceneStore.scene.getMaterialByName('grid_visible')) !== null && _sceneStore$scene$get !== void 0 ? _sceneStore$scene$get : new PBRMaterial('grid_visible', sceneStore.scene);
    box.material.alpha = 0.6;
    if (!isFree) {
      var _sceneStore$scene$get2;
      box.material = (_sceneStore$scene$get2 = sceneStore.scene.getMaterialByName('grid_invisible')) !== null && _sceneStore$scene$get2 !== void 0 ? _sceneStore$scene$get2 : new PBRMaterial('grid_invisible', sceneStore.scene);
      box.material.alpha = 0;
    }
    box.enableEdgesRendering();
    box.edgesWidth = 0.2;
    box.edgesColor = new Color4(0.15, 0.15, 0.3, 1);
    box.material.environmentIntensity = 0;
    box.material.emissiveColor = new Color3(0.5, 0.5, 0.5);
    Tags.AddTagsTo(box, 'grid');
    Tags.AddTagsTo(box, isFree ? 'free' : 'planned');
    Tags.AddTagsTo(box, noDelete ? 'disableDelete' : 'allowDelete');
    Tags.AddTagsTo(box, noMove ? 'disableMove' : 'allowMove');
    Tags.AddTagsTo(box, 'ac:' + articleCodex);
    // the actionmanager can't use the bbox, therefore need to fake it https://forum.babylonjs.com/t/action-manager-pointer-trigger-with-bounding-box/43891
    var fakeBBox = MeshBuilder.CreateBox('binfo_' + box.name, {
      width: data.bboxSize.x / 99,
      height: data.bboxSize.y / 99,
      depth: data.bboxSize.z / 99
    }, sceneStore.scene);
    fakeBBox.metadata = {
      elementId: elementId,
      rulePos: {
        x: data.rulePosition.x / 100,
        y: data.rulePosition.y / 100,
        z: data.rulePosition.z / 100
      },
      geoPos: new Vector3(data.geoPosition.x / 100, data.geoPosition.y / 100, data.geoPosition.z / 100)
    };
    fakeBBox.parent = box;
    fakeBBox.position = Vector3.Zero();
    fakeBBox.isPickable = true;
    fakeBBox.setEnabled(true);
    fakeBBox.isVisible = false;
    fakeBBox.enablePointerMoveEvents = true;
    fakeBBox.actionManager = new ActionManager(sceneStore.scene);
    fakeBBox.actionManager.hoverCursor = 'pointer';
    fakeBBox.actionManager.registerAction(new ExecuteCodeAction(ActionManager.OnPointerOverTrigger, function () {
      return box.edgesWidth = 0.5;
    }));
    fakeBBox.actionManager.registerAction(new ExecuteCodeAction(ActionManager.OnPickTrigger, function () {
      return onGridClick(gridStore.getSelectedGrid());
    }));
    fakeBBox.actionManager.registerAction(new ExecuteCodeAction(ActionManager.OnPickDownTrigger, function () {
      return gridStore.selectedGrid == gridStore.getSelectedGrid() && noMove == false && gridStore.onGridMove(gridStore.getSelectedGrid());
    }));
    fakeBBox.actionManager.registerAction(new ExecuteCodeAction(ActionManager.OnPointerOutTrigger, function () {
      return box.edgesWidth = 0.2;
    }));
    if (gridStore.selectedGrid && box.name == gridStore.selectedGrid.name && utilStore.viewHandler && Tags.GetTags(gridStore.selectedGrid).includes('ac:' + articleCodex)) {
      var _gridStore$plannedPla;
      var basketId = (_gridStore$plannedPla = gridStore.plannedPlacesOnGrids) === null || _gridStore$plannedPla === void 0 || (_gridStore$plannedPla = _gridStore$plannedPla.find(function (plannedPlacesOnGrid) {
        return plannedPlacesOnGrid.elementId == elementId;
      })) === null || _gridStore$plannedPla === void 0 ? void 0 : _gridStore$plannedPla.basketId;
      if (basketId) gridStore.selectGrid(box, gridIdx, shelfIdx, basketId, noDelete, noMove);
    }
  }
  function onGridClick(mesh) {
    var _gridStore$selectedGr;
    if (!utilStore.viewHandler) return;
    var tag = Tags.GetTags(mesh);
    var _ref = gridStore.getDataFromGridName(mesh.name, mesh.metadata.elementId),
      basketId = _ref.parentBasketId,
      gridIdx = _ref.gridIdx,
      shelfIdx = _ref.shelfIdx;
    var plannedPlace = _plannedPlaceOnGrids.find(function (plannedPlace) {
      return plannedPlace.elementId == mesh.metadata.elementId;
    });
    var grid = Object.entries(plannedPlace.grids).find(function (_ref2) {
      var _ref3 = _slicedToArray(_ref2, 2);
        _ref3[0];
        var grid = _ref3[1];
      return grid.idx == gridIdx;
    })[1];
    var accessorie = grid.accessories.find(function (accessorie) {
      return accessorie.index == shelfIdx;
    });
    if (tag.includes('free') && mesh.id !== ((_gridStore$selectedGr = gridStore.selectedGrid) === null || _gridStore$selectedGr === void 0 ? void 0 : _gridStore$selectedGr.id)) {
      gridStore.selectGrid(mesh, gridIdx, shelfIdx, basketId, tag.includes('disableDelete'), tag.includes('disableMove'));
      utilStore.viewHandler.paletteViewHandler.addAccessorieOnShelfPlannerView(gridIdx, shelfIdx, basketId);
    } else {
      utilStore.viewHandler.paletteViewHandler.selectShelfAccessorie(accessorie === null || accessorie === void 0 ? void 0 : accessorie.articleCodex, accessorie === null || accessorie === void 0 ? void 0 : accessorie.basketId);
      gridStore.selectGrid(mesh, gridIdx, shelfIdx, basketId, tag.includes('disableDelete'), tag.includes('disableMove'));
    }
    return;
  }
  return {
    setupPreviewGrids: setupPreviewGrids,
    onGridClick: onGridClick,
    deleteAllGrids: deleteAllGrids
  };
}

/* 
  SceneStore
  Wraps the scene with additional data and methods
*/
var GridStore = /*#__PURE__*/function () {
  function GridStore(sceneStore, uiStore, viewHandler) {
    _classCallCheck(this, GridStore);
    _defineProperty(this, "_gridControls", undefined);
    _defineProperty(this, "_allGrids", void 0);
    _defineProperty(this, "_plannedOptions", void 0);
    _defineProperty(this, "_grid", undefined);
    _defineProperty(this, "_freePlacesOnGrids", void 0);
    _defineProperty(this, "_plannedPlacesOnGrids", void 0);
    _defineProperty(this, "_sceneStore", void 0);
    _defineProperty(this, "_viewHandler", void 0);
    _defineProperty(this, "_selectedGrid", void 0);
    _defineProperty(this, "_uiStore", void 0);
    this._sceneStore = sceneStore;
    this._viewHandler = viewHandler;
    this._uiStore = uiStore;
  }
  return _createClass(GridStore, [{
    key: "plannedPlacesOnGrids",
    get: function get() {
      return this._plannedPlacesOnGrids;
    }
  }, {
    key: "freePlacesOnGrids",
    get: function get() {
      return this._freePlacesOnGrids;
    }
  }, {
    key: "selectedGrid",
    get: function get() {
      return this._selectedGrid;
    }
  }, {
    key: "getSelectedGrid",
    value: function getSelectedGrid() {
      var pickInfo = this._sceneStore.scene.multiPick(this._sceneStore.scene.pointerX, this._sceneStore.scene.pointerY);
      var pickedGrids = pickInfo === null || pickInfo === void 0 ? void 0 : pickInfo.filter(function (pick) {
        var _Tags$GetTags;
        return (_Tags$GetTags = Tags.GetTags(pick.pickedMesh)) === null || _Tags$GetTags === void 0 ? void 0 : _Tags$GetTags.includes('grid');
      });
      return pickedGrids[pickedGrids.length - 1].pickedMesh;
    }
  }, {
    key: "onGridMove",
    value: function onGridMove(box) {
      var _ref = this.getDataFromGridName(box.name, box.metadata.elementId),
        accessoireBasketId = _ref.accessoireBasketId,
        parentBasketId = _ref.parentBasketId,
        gridIdx = _ref.gridIdx,
        shelfIdx = _ref.shelfIdx,
        gridName = _ref.gridName;
      this.getMoveGrids(gridName, accessoireBasketId);
      this._gridControls = getGridControls(this._sceneStore.scene, this._sceneStore.scene.getEngine().getRenderingCanvas(), this._sceneStore.scene.getMeshByName(box.name), this._sceneStore.elements, this.selectGrid.bind(this));
      this._gridControls.register(parentBasketId, gridIdx, shelfIdx, accessoireBasketId);
    }
  }, {
    key: "selectGrid",
    value: function selectGrid(mesh, gridIdx, shelfIdx, basketId, disableDelete, disableMove) {
      var _this = this;
      this._sceneStore.scene.getMeshesByTags('grid').forEach(function (mesh) {
        return mesh.edgesWidth = 0.2;
      });
      mesh.edgesWidth = 0.7;
      mesh.enableEdgesRendering();
      this._selectedGrid = mesh;
      this._uiStore.createGridGui(this._selectedGrid, !disableDelete ? function () {
        _this._viewHandler.paletteViewHandler.deleteAccessorieOnShelfPlannerView(gridIdx, shelfIdx, basketId);
        _this.deselectGrids(false);
      } : undefined);
      if (!disableMove) this._sceneStore.scene.getMeshByName('binfo_' + this._selectedGrid.name).actionManager.hoverCursor = 'move';
    }
  }, {
    key: "getMoveGrids",
    value: function () {
      var _getMoveGrids = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(gridName, basketId) {
        var _this$_viewHandler;
        var fp;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              fp = (_this$_viewHandler = this._viewHandler) === null || _this$_viewHandler === void 0 ? void 0 : _this$_viewHandler.divaWebPlanner.getFreeToMovePlacesOnGrids(gridName, basketId);
              if (!(!fp || !this._plannedPlacesOnGrids)) {
                _context.next = 3;
                break;
              }
              return _context.abrupt("return");
            case 3:
              this.getGrids(fp, this._plannedPlacesOnGrids, true, true);
            case 4:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function getMoveGrids(_x, _x2) {
        return _getMoveGrids.apply(this, arguments);
      }
      return getMoveGrids;
    }()
  }, {
    key: "deselectGrids",
    value: function deselectGrids() {
      var triggerUpdate = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
      if (triggerUpdate) {
        var _this$_viewHandler2;
        if (!this._viewHandler || !this._freePlacesOnGrids || !this._viewHandler.tabgroupTypeActive('SHELFPLANNER')) return;
        (_this$_viewHandler2 = this._viewHandler) === null || _this$_viewHandler2 === void 0 || _this$_viewHandler2.paletteViewHandler.selectShelfAccessorie(undefined);
        if (this._selectedGrid) {
          var bboxGrid = this._sceneStore.scene.getMeshByName('binfo_' + this._selectedGrid.name);
          if (!bboxGrid) return;
          bboxGrid.actionManager.hoverCursor = 'pointer';
        }
      }
      this._selectedGrid = undefined;
      this._uiStore.removeGridGui();
    }
  }, {
    key: "rerenderGrids",
    value: function rerenderGrids() {
      if (!this._freePlacesOnGrids || !this._plannedPlacesOnGrids) return;
      this.getGrids(this._freePlacesOnGrids, this._plannedPlacesOnGrids);
    }
  }, {
    key: "_buildPlannedOptions",
    value: function _buildPlannedOptions(plannedPlacesOnGrids) {
      var res = [];
      plannedPlacesOnGrids.forEach(function (plannedPlaceOnGrid) {
        return res.push({
          elementId: plannedPlaceOnGrid.elementId,
          plannedOptions: plannedPlaceOnGrid.plannedOptions
        });
      });
      return res;
    }
  }, {
    key: "getGrids",
    value: function () {
      var _getGrids = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(freePlacesOnGrids, plannedPlacesOnGrids, doNotRelod, doNotOverwrite) {
        var _this$_viewHandler3, _this$_viewHandler4;
        var _this$_sceneStore$api, res;
        return _regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              if (!this._grid) this._grid = Grids();
              if (!(!((_this$_viewHandler3 = this._viewHandler) !== null && _this$_viewHandler3 !== void 0 && _this$_viewHandler3.tabgroupTypeActive('SHELFPLANNER')) || !freePlacesOnGrids && !plannedPlacesOnGrids)) {
                _context2.next = 5;
                break;
              }
              this._grid.deleteAllGrids();
              this._uiStore.removeGridGui();
              return _context2.abrupt("return");
            case 5:
              if (!(!doNotRelod && plannedPlacesOnGrids && JSON.stringify(plannedPlacesOnGrids[0].plannedOptions) != JSON.stringify(this._plannedOptions))) {
                _context2.next = 15;
                break;
              }
              this._plannedOptions = this._buildPlannedOptions(plannedPlacesOnGrids);
              plannedPlacesOnGrids.forEach(function (pP) {
                return pP.shelf3DName;
              });
              _context2.next = 10;
              return fetch(((_this$_sceneStore$api = this._sceneStore.apiConfig) === null || _this$_sceneStore$api === void 0 ? void 0 : _this$_sceneStore$api.constructorService) + '/articles/grids/all?catalogCodex=' + plannedPlacesOnGrids[0].catalogCodex + '&catalogILN=' + plannedPlacesOnGrids[0].iln + '&debug=' + !!this._sceneStore.apiConfig.useDebugUrl, {
                headers: {
                  Authorization: "Bearer ".concat(this._sceneStore.jwt),
                  'Content-Type': 'application/json'
                },
                method: 'POST',
                body: JSON.stringify({
                  plannedPlacesOnGrids: plannedPlacesOnGrids,
                  freePlacesOnGrids: freePlacesOnGrids !== null && freePlacesOnGrids !== void 0 ? freePlacesOnGrids : []
                })
              });
            case 10:
              res = _context2.sent;
              this._plannedOptions = this._buildPlannedOptions(plannedPlacesOnGrids);
              _context2.next = 14;
              return res.json();
            case 14:
              this._allGrids = _context2.sent;
            case 15:
              if (this._allGrids) {
                _context2.next = 17;
                break;
              }
              return _context2.abrupt("return");
            case 17:
              if (!(!((_this$_viewHandler4 = this._viewHandler) !== null && _this$_viewHandler4 !== void 0 && _this$_viewHandler4.tabgroupTypeActive('SHELFPLANNER')) || !freePlacesOnGrids && !plannedPlacesOnGrids)) {
                _context2.next = 21;
                break;
              }
              this._grid.deleteAllGrids();
              this._uiStore.removeGridGui();
              return _context2.abrupt("return");
            case 21:
              this._grid.setupPreviewGrids(this._allGrids, plannedPlacesOnGrids, freePlacesOnGrids);
              if (!doNotOverwrite) {
                this._freePlacesOnGrids = freePlacesOnGrids;
                this._plannedPlacesOnGrids = plannedPlacesOnGrids;
              }
            case 23:
            case "end":
              return _context2.stop();
          }
        }, _callee2, this);
      }));
      function getGrids(_x3, _x4, _x5, _x6) {
        return _getGrids.apply(this, arguments);
      }
      return getGrids;
    }()
  }, {
    key: "getDataFromGridName",
    value: function getDataFromGridName(name, elementId) {
      var _this$plannedPlacesOn, _this$_plannedPlacesO, _accessories$find;
      if (!this._viewHandler) return;
      name = name.replace(elementId, '');
      var gridIdx = Number(name.slice(name.indexOf('.', name.indexOf('.')) + 1, name.indexOf('.', name.indexOf('.') + 1)));
      var shelfIdx = Number(name.slice(name.indexOf('.', name.indexOf('.', name.indexOf('.') + 1)) + 1, name.lastIndexOf('.')));
      var gridName = name.slice(name.lastIndexOf('.') + 1, name.length);
      var parentBasketId = (_this$plannedPlacesOn = this.plannedPlacesOnGrids) === null || _this$plannedPlacesOn === void 0 ? void 0 : _this$plannedPlacesOn.find(function (plannedPlaceOnGrid) {
        return plannedPlaceOnGrid.elementId == elementId;
      }).basketId;
      var grid = (_this$_plannedPlacesO = this._plannedPlacesOnGrids) === null || _this$_plannedPlacesO === void 0 || (_this$_plannedPlacesO = _this$_plannedPlacesO.find(function (p) {
        return p.basketId == parentBasketId;
      })) === null || _this$_plannedPlacesO === void 0 ? void 0 : _this$_plannedPlacesO.grids[gridName];
      var accessoireBasketId = (_accessories$find = grid.accessories.find(function (ac) {
        return ac.index == shelfIdx;
      })) === null || _accessories$find === void 0 ? void 0 : _accessories$find.basketId;
      return {
        elementId: elementId,
        gridIdx: gridIdx,
        shelfIdx: shelfIdx,
        parentBasketId: parentBasketId,
        accessoireBasketId: accessoireBasketId,
        gridName: gridName
      };
    }
  }]);
}();

var lightning = function lightning(diva3durl, scene, cams, isMobile, sceneStore) {
  var environmentTexture = CubeTexture.CreateFromPrefilteredData(diva3durl + 'environment.env', scene);
  environmentTexture.gammaSpace = false;
  environmentTexture.rotationY = 1.45;
  scene.environmentTexture = environmentTexture;
  scene.createDefaultSkybox(environmentTexture);
  scene.environmentIntensity = 1;
  scene.getMaterialByName('skyBox').alpha = 0;
  var ssao = new SSAO2RenderingPipeline('ssao', scene, {
    ssaoRatio: 0.5,
    // Ratio of the SSAO post-process, in a lower resolution
    blurRatio: 0.5 // Ratio of the combine post-process (combines the SSAO and the scene)
  }, cams);
  ssao.radius = 1.25;
  ssao.epsilon = 0.002;
  ssao.totalStrength = 0.7;
  ssao.bilateralTolerance = 0.1;
  ssao.base = 0;
  ssao.expensiveBlur = true;
  ssao.bilateralSamples = 32;
  ssao.bilateralSoften = 0.7;
  ssao.maxZ = 25;
  ssao.minZAspect = 0.01;
  var maxSamples = 12;
  ssao.samples = maxSamples;
  scene.prePassRenderer.samples = maxSamples;
  sceneStore.ssao = ssao;
};

function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function createCams(scene, viewpoint) {
  var _useUtilStoreContext = useUtilStoreContext(),
    vector3ToBVector3 = _useUtilStoreContext.vector3ToBVector3,
    degreesToRadians = _useUtilStoreContext.degreesToRadians;
  function createCam(_ref) {
    var name = _ref.name,
      pos = _ref.pos,
      rot = _ref.rot,
      isEnabled = _ref.isEnabled,
      parent = _ref.parent,
      target = _ref.target;
    var existingCam = scene.getCameraByName(name);
    if (existingCam) return existingCam;
    var camera = new UniversalCamera(name, pos, scene);
    camera.rotation = degreesToRadians(rot);
    camera.minZ = 0.1;
    camera.maxZ = 30;
    camera.fov = 0.418879;
    if (isEnabled) scene.activeCamera = camera;
    if (parent) camera.parent = parent;
    var canvas = scene.getEngine().getRenderingCanvas();
    camera.inputs.clear();
    camera.inputs.removeByType('FreeCameraKeyboardMoveInput');
    camera.inputs.removeByType('FreeCameraMouseInput');
    camera.inputs.add(GetCameraControls(camera));
    // only control the current active Cam
    if (isEnabled) {
      camera.attachControl(canvas, true);
    }
    if (target) camera.target = target;
    return camera;
  }
  function createDefaultCam() {
    return [createCam({
      name: 'defaultCam',
      isEnabled: true,
      pos: new Vector3(4.5, 2.2, 8),
      rot: new Vector3(7.75, -150, 0),
      parent: undefined
    })];
  }
  if (scene.activeCamera) return [scene.activeCamera];
  if (!viewpoint) return createDefaultCam();
  return [createCam({
    name: 'defaultCam',
    isEnabled: true,
    pos: vector3ToBVector3(viewpoint.pos).multiply(new Vector3(-0.01, 0.01, 0.01)),
    rot: vector3ToBVector3(_objectSpread$1(_objectSpread$1({}, viewpoint.rot), {}, {
      x: -viewpoint.rot.x
    })),
    target: vector3ToBVector3(viewpoint.targetPos).multiply(new Vector3(-0.01, 0.01, 0.01)),
    parent: undefined
  })];
}
function updateCam(camera, scene) {
  var _sceneStore$updateCam;
  if (camera.pos.x == 0 && camera.pos.y == 0 && camera.pos.z == 0) return;
  var utilStore = useUtilStoreContext();
  var sceneStore = useSceneStoreContext();
  var cam = scene.getCameraByName('defaultCam');
  if (!cam) {
    var _cam = createCams(scene, camera)[0];
    sceneStore.targetCameraPosition = _cam.position;
    sceneStore.cameraTargetPosition = _cam.target;
    return;
  }
  if (camera.pos.x == cam.position.x && camera.pos.y == cam.position.y && camera.pos.z == camera.pos.z) return;
  var position = utilStore.vector3ToBVector3(camera.pos).multiply(new Vector3(-0.01, 0.01, 0.01));
  var rotation = utilStore.degreesToRadians(utilStore.vector3ToBVector3(_objectSpread$1(_objectSpread$1({}, camera.rot), {}, {
    x: -camera.rot.x
  })));
  var target = utilStore.vector3ToBVector3(camera.targetPos).multiply(new Vector3(-0.01, 0.01, 0.01));
  cam.position = position;
  cam.rotation = rotation;
  cam.setTarget(target);
  sceneStore.targetCameraPosition = position;
  sceneStore.cameraTargetPosition = target;
  (_sceneStore$updateCam = sceneStore.updateCameraInformation) === null || _sceneStore$updateCam === void 0 || _sceneStore$updateCam.call(sceneStore, {
    horiFov: cam.fov * 180 / Math.PI,
    lensShiftX: 0,
    lensShiftY: 0,
    name: cam.name,
    pos: {
      x: position.x,
      y: position.y,
      z: position.z
    },
    rot: {
      x: rotation.x * 180 / Math.PI,
      y: rotation.y * 180 / Math.PI,
      z: rotation.z * 180 / Math.PI
    },
    targetPos: {
      x: target.x,
      y: target.y,
      z: target.z
    },
    vertFov: cam.fov * 180 / Math.PI
  });
}

function shadow() {
  var _useSceneStoreContext = useSceneStoreContext(),
    hasRendered = _useSceneStoreContext.hasRendered,
    scene = _useSceneStoreContext.scene;
  var _useUtilStoreContext = useUtilStoreContext(),
    degreesToRadians = _useUtilStoreContext.degreesToRadians;
  if (!hasRendered && !scene.getMeshByName('ground')) {
    var light = new DirectionalLight('dirl', new Vector3(-1, 0, 0), scene);
    var lightf = new DirectionalLight('dirf', new Vector3(0, -0.436, -0.9), scene);
    var lightr = new DirectionalLight('dirr', new Vector3(0, -1, 0.3), scene);
    var lightl = new DirectionalLight('dirb', new Vector3(0.2, -1, 0.2), scene);
    lightl.intensity = 1;
    lightf.intensity = 2.2;
    light.intensity = 1;
    lightr.intensity = 1;
    light.position = new Vector3(-2, 5, 0);
    lightf.position = new Vector3(2, 5, 0);
    lightr.position = new Vector3(0, 5, -2);
    lightl.position = new Vector3(0, 5, -2);
    var ground = MeshBuilder.CreatePlane('ground', {
      width: 100,
      height: 100
    }, scene);
    ground.receiveShadows = true;
    ground.position = new Vector3(0, 0, 0);
    ground.rotation = degreesToRadians({
      x: 90,
      y: 0,
      z: 0
    });
    var std_mat = new PBRMetallicRoughnessMaterial('std_mat', scene);
    std_mat.metallic = 0;
    scene.defaultMaterial = std_mat;
    var mat = new PBRMetallicRoughnessMaterial('white', scene);
    mat.metallic = 0.05;
    mat.roughness = 1;
    mat._environmentIntensity = 0;
    mat.clearCoat.isEnabled = true;
    mat.clearCoat.intensity = 1;
    mat.subSurface.isTranslucencyEnabled = true;
    ground.material = mat;
  }
}

function _createForOfIteratorHelper$7(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$7(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$7(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$7(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$7(r, a) : void 0; } }
function _arrayLikeToArray$7(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
/* 
  SceneStore
  Wraps the scene with additional data and methods
*/
var SceneStore = /*#__PURE__*/function () {
  function SceneStore(scene, hqRenderScript, utilStore, apiConfig, jwt, onMissingGeo, updateCameraInformation) {
    var _this = this;
    _classCallCheck(this, SceneStore);
    _defineProperty(this, "_hqRenderScript", void 0);
    _defineProperty(this, "_previousHQRenderScript", void 0);
    _defineProperty(this, "_scene", void 0);
    _defineProperty(this, "_cams", []);
    _defineProperty(this, "_geos", []);
    _defineProperty(this, "_sceneConstruct", {});
    _defineProperty(this, "_hasRendered", false);
    _defineProperty(this, "_hasPlanned", false);
    _defineProperty(this, "_modelIteration", 0);
    _defineProperty(this, "_utilStore", void 0);
    _defineProperty(this, "_cache", []);
    _defineProperty(this, "_ssao", undefined);
    _defineProperty(this, "_renderPipeline", undefined);
    _defineProperty(this, "_isInitializing", false);
    _defineProperty(this, "_optimizer", void 0);
    _defineProperty(this, "_apiConfig", void 0);
    _defineProperty(this, "_jwt", void 0);
    _defineProperty(this, "_onMissingGeo", void 0);
    _defineProperty(this, "_cancelSceneExport", void 0);
    _defineProperty(this, "_materialCache", void 0);
    //controls
    _defineProperty(this, "_renderControlLoop", undefined);
    _defineProperty(this, "_doRenderControlLoop", false);
    _defineProperty(this, "_cameraTargetPosition", Vector3.Zero());
    _defineProperty(this, "_targetCameraPosition", Vector3.Zero());
    _defineProperty(this, "_selectedElements", void 0);
    _defineProperty(this, "_focusedElement", void 0);
    _defineProperty(this, "_isControlledViewpoint", true);
    // if the current viewpoint should automatically change with the planning
    _defineProperty(this, "_renderLoopTimeoutId", void 0);
    _defineProperty(this, "light", undefined);
    _defineProperty(this, "changedElements", void 0);
    _defineProperty(this, "updateCameraInformation", void 0);
    scene.clearColor = new Color4(1, 1, 1, 1);
    this._scene = scene;
    this._apiConfig = apiConfig;
    this._onMissingGeo = onMissingGeo;
    this.updateCameraInformation = updateCameraInformation;
    this._cancelSceneExport = false;
    this._jwt = jwt;
    this._materialCache = [];
    this._hqRenderScript = JSON.parse(hqRenderScript);
    this._utilStore = utilStore;
    var options = new SceneOptimizerOptions(30, 1000);
    options.addOptimization(new ShadowsOptimization(0));
    options.addOptimization(new RenderTargetsOptimization(0));
    options.addCustomOptimization(function (scene, optimizer) {
      scene.materials.forEach(function (mat) {
        return mat.freeze();
      });
      scene.blockMaterialDirtyMechanism = true;
      return true;
    }, function () {
      return '';
    }, 0);
    options.addCustomOptimization(function () {
      if (!_this._ssao) return false;
      _this._ssao.dispose();
      return true;
    }, function () {
      return '';
    }, 1);
    this._optimizer = new SceneOptimizer(scene, options);
  }
  return _createClass(SceneStore, [{
    key: "materialCache",
    get: function get() {
      return this._materialCache;
    }
  }, {
    key: "modelIteration",
    get: function get() {
      return this._modelIteration;
    }
  }, {
    key: "jwt",
    get: function get() {
      return this._jwt;
    }
  }, {
    key: "apiConfig",
    get: function get() {
      return this._apiConfig;
    }
  }, {
    key: "scene",
    get: function get() {
      return this._scene;
    }
  }, {
    key: "sets",
    get: function get() {
      var _this$_sceneConstruct;
      return (_this$_sceneConstruct = this._sceneConstruct.root) === null || _this$_sceneConstruct === void 0 ? void 0 : _this$_sceneConstruct.sets;
    }
  }, {
    key: "geos",
    get: function get() {
      return this._geos;
    }
  }, {
    key: "cache",
    get: function get() {
      return this._cache;
    },
    set: function set(ch) {
      this._cache = ch;
    }
  }, {
    key: "doRenderControlLoop",
    get: function get() {
      return this._doRenderControlLoop;
    },
    set: function set(doRenderControlLoop) {
      this._doRenderControlLoop = doRenderControlLoop;
    }
  }, {
    key: "selectedElements",
    get: function get() {
      return this._selectedElements;
    },
    set: function set(element) {
      this._selectedElements = element;
    }
  }, {
    key: "focusedElement",
    get: function get() {
      var _this$_focusedElement;
      if (!this._focusedElement) {
        var root = this.scene.getTransformNodeByName('Root');
        if (root) {
          var bbox = root.getHierarchyBoundingVectors();
          this._focusedElement = {
            id: this.getId(root),
            name: 'Root',
            position: root.absolutePosition,
            size: Vector3.Distance(bbox.min, bbox.max)
          };
        }
      }
      return (_this$_focusedElement = this._focusedElement) !== null && _this$_focusedElement !== void 0 ? _this$_focusedElement : {
        id: 'Root',
        name: 'Root',
        position: Vector3.Zero(),
        size: 0
      };
    },
    set: function set(val) {
      this._focusedElement = val;
    }
  }, {
    key: "isControlledViewpoint",
    get: function get() {
      return !!this._isControlledViewpoint;
    },
    set: function set(value) {
      this._isControlledViewpoint = value;
    }
  }, {
    key: "controlRenderLoop",
    get: function get() {
      return this._renderControlLoop;
    },
    set: function set(renderLoop) {
      this._renderControlLoop = renderLoop;
    }
  }, {
    key: "hqRenderScript",
    get: function get() {
      return this._hqRenderScript;
    },
    set: function set(hqRenderScript) {
      this._previousHQRenderScript = this._hqRenderScript;
      this._hqRenderScript = hqRenderScript;
    }
  }, {
    key: "root",
    get: function get() {
      return this._sceneConstruct.root;
    }
  }, {
    key: "mainElements",
    get: function get() {
      var _this$_sceneConstruct2;
      var elms = [];
      if (!((_this$_sceneConstruct2 = this._sceneConstruct.root) !== null && _this$_sceneConstruct2 !== void 0 && _this$_sceneConstruct2.sets)) return [];
      var _iterator = _createForOfIteratorHelper$7(this._sceneConstruct.root.sets),
        _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var set = _step.value;
          var _iterator2 = _createForOfIteratorHelper$7(set.elements),
            _step2;
          try {
            for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
              var element = _step2.value;
              var name = element.bbn.name;
              var elId = name.slice(name.lastIndexOf('E'), name.length);
              if (elId.split('.').length == 1) elms.push(element);
            }
          } catch (err) {
            _iterator2.e(err);
          } finally {
            _iterator2.f();
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
      return elms;
    }
  }, {
    key: "elements",
    get: function get() {
      var _this$_sceneConstruct3;
      var elms = [];
      if (!((_this$_sceneConstruct3 = this._sceneConstruct.root) !== null && _this$_sceneConstruct3 !== void 0 && _this$_sceneConstruct3.sets)) return [];
      var _iterator3 = _createForOfIteratorHelper$7(this._sceneConstruct.root.sets),
        _step3;
      try {
        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
          var set = _step3.value;
          var _iterator4 = _createForOfIteratorHelper$7(set.elements),
            _step4;
          try {
            for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
              var element = _step4.value;
              elms.push(element);
            }
          } catch (err) {
            _iterator4.e(err);
          } finally {
            _iterator4.f();
          }
        }
      } catch (err) {
        _iterator3.e(err);
      } finally {
        _iterator3.f();
      }
      return elms;
    }
  }, {
    key: "cameraTargetPosition",
    get: function get() {
      return this._cameraTargetPosition;
    },
    set: function set(pos) {
      this._cameraTargetPosition = pos;
    }
  }, {
    key: "targetCameraPosition",
    get: function get() {
      return this._targetCameraPosition;
    },
    set: function set(pos) {
      this._targetCameraPosition = pos;
    }
  }, {
    key: "isInitializing",
    get: function get() {
      return this._isInitializing;
    },
    set: function set(isInit) {
      this._isInitializing = isInit;
    }
  }, {
    key: "enableSSAO",
    value: function enableSSAO(enable) {
      if (!this._ssao) return;
      this._ssao.totalStrength = enable ? 0.7 : 0;
    }
  }, {
    key: "getElementByName",
    value: function getElementByName(name) {
      var _this$_sceneConstruct4, _this$_sceneConstruct5;
      if (!((_this$_sceneConstruct4 = this._sceneConstruct.root) !== null && _this$_sceneConstruct4 !== void 0 && _this$_sceneConstruct4.sets)) return undefined;
      var _iterator5 = _createForOfIteratorHelper$7((_this$_sceneConstruct5 = this._sceneConstruct.root) === null || _this$_sceneConstruct5 === void 0 ? void 0 : _this$_sceneConstruct5.sets),
        _step5;
      try {
        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
          var set = _step5.value;
          var _iterator6 = _createForOfIteratorHelper$7(set.elements),
            _step6;
          try {
            for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
              var element = _step6.value;
              if (element.bbn.name == name) return element;
            }
          } catch (err) {
            _iterator6.e(err);
          } finally {
            _iterator6.f();
          }
        }
      } catch (err) {
        _iterator5.e(err);
      } finally {
        _iterator5.f();
      }
      return undefined;
    }
  }, {
    key: "getElementNameById",
    value: function getElementNameById(id) {
      var _this$_sceneConstruct6, _this$_sceneConstruct7;
      if (!((_this$_sceneConstruct6 = this._sceneConstruct.root) !== null && _this$_sceneConstruct6 !== void 0 && _this$_sceneConstruct6.sets)) return undefined;
      var _iterator7 = _createForOfIteratorHelper$7((_this$_sceneConstruct7 = this._sceneConstruct.root) === null || _this$_sceneConstruct7 === void 0 ? void 0 : _this$_sceneConstruct7.sets),
        _step7;
      try {
        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
          var set = _step7.value;
          var _iterator8 = _createForOfIteratorHelper$7(set.elements),
            _step8;
          try {
            for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
              var element = _step8.value;
              var nm = element.bbn.name;
              var elementPos = nm.slice(nm.lastIndexOf('E') + 1, nm.length);
              if (elementPos == id.toString()) {
                return element.bbn.name;
              }
            }
          } catch (err) {
            _iterator8.e(err);
          } finally {
            _iterator8.f();
          }
        }
      } catch (err) {
        _iterator7.e(err);
      } finally {
        _iterator7.f();
      }
      return undefined;
    }
  }, {
    key: "hasRendered",
    get: function get() {
      return this._hasRendered;
    },
    set: function set(value) {
      if (!value) throw new Error("can't unrender");
      this._hasRendered = value;
    }
  }, {
    key: "hasPlanned",
    get: function get() {
      return this._hasPlanned;
    },
    set: function set(value) {
      if (!value) throw new Error("can't set has planned to false");
      this._hasPlanned = value;
    }
  }, {
    key: "cams",
    get: function get() {
      return this._cams;
    }
  }, {
    key: "previousHQRenderScript",
    get: function get() {
      return this._previousHQRenderScript;
    }
  }, {
    key: "activeCamera",
    get: function get() {
      return this._scene.activeCamera;
    }
  }, {
    key: "meshes",
    get: function get() {
      return this._scene.meshes;
    }
  }, {
    key: "ssao",
    get: function get() {
      return this._ssao;
    },
    set: function set(ssao) {
      this._ssao = ssao;
    }
  }, {
    key: "renderPipeline",
    get: function get() {
      return this._renderPipeline;
    },
    set: function set(renderPipeline) {
      this._renderPipeline = renderPipeline;
    }
  }, {
    key: "renderLoop",
    value: function renderLoop() {
      var _this$controlRenderLo;
      if (!this.scene.isReady() || !this.activeCamera) return;
      if (this.cameraTargetPosition.x == 0 && this.cameraTargetPosition.y == 0 && this.cameraTargetPosition.z == 0) this.setCameraTarget();
      (_this$controlRenderLo = this.controlRenderLoop) === null || _this$controlRenderLo === void 0 || _this$controlRenderLo.call(this);
      this.scene.render();
    }
  }, {
    key: "runRenderLoop",
    value: function runRenderLoop() {
      var engine = this._scene.getEngine();
      if (engine.activeRenderLoops.length != 0) return;
      engine.runRenderLoop(this.renderLoop.bind(this));
    }
  }, {
    key: "runRenderLoopIndefinitely",
    value: function runRenderLoopIndefinitely() {
      clearTimeout(this._renderLoopTimeoutId);
      this.runRenderLoop();
    }
  }, {
    key: "runRenderLoopForTime",
    value: function runRenderLoopForTime(ms) {
      var _this2 = this;
      this.runRenderLoop();
      clearTimeout(this._renderLoopTimeoutId);
      this._renderLoopTimeoutId = setTimeout(function () {
        _this2.stopRenderLoop();
      }, ms);
    }
  }, {
    key: "stopRenderLoop",
    value: function stopRenderLoop() {
      clearTimeout(this._renderLoopTimeoutId);
      this._renderLoopTimeoutId = undefined;
      this._scene.getEngine().stopRenderLoop();
    }
  }, {
    key: "setResolution",
    value: function setResolution(gameCanvas, resolution) {
      if (!resolution || !gameCanvas) return;
      var boundingClientRect = gameCanvas.getBoundingClientRect();
      var maxX = boundingClientRect.right - boundingClientRect.left;
      var maxY = boundingClientRect.bottom - boundingClientRect.top;
      var ratio = Math.min(maxX / resolution.x, maxY / resolution.y);
      if (resolution.x > maxX || resolution.y > maxY) {
        gameCanvas.style.width = (resolution.x * ratio).toString() + 'px';
        gameCanvas.style.height = (resolution.y * ratio).toString() + 'px';
      } else {
        gameCanvas.style.width = resolution.x.toString() + 'px';
        gameCanvas.style.height = resolution.y.toString() + 'px';
      }
      this._scene.getEngine().resize();
    }
  }, {
    key: "checkMaterialCache",
    value: function checkMaterialCache() {
      // material cache can't go over amount x because it leads to performance issues
      if (this._materialCache.length < 10) return;
      var amountToDispose = this._materialCache.length - 11;
      var disposableMaterials = this._materialCache.filter(function (m) {
        return m.mat.getBindedMeshes().length == 0;
      });
      disposableMaterials = disposableMaterials.sort(function (dm) {
        return dm.lastUsage;
      });
      for (var idx = 0; idx < amountToDispose; idx++) {
        if (idx < disposableMaterials.length - 1) {
          var _mat$baseTexture, _mat$metallicRoughnes, _mat$normalTexture;
          var mat = disposableMaterials[idx].mat;
          mat.dispose();
          (_mat$baseTexture = mat.baseTexture) === null || _mat$baseTexture === void 0 || _mat$baseTexture.dispose();
          (_mat$metallicRoughnes = mat.metallicRoughnessTexture) === null || _mat$metallicRoughnes === void 0 || _mat$metallicRoughnes.dispose();
          (_mat$normalTexture = mat.normalTexture) === null || _mat$normalTexture === void 0 || _mat$normalTexture.dispose();
          this._materialCache.splice(this._materialCache.indexOf(disposableMaterials[idx]), 1);
        }
      }
    }
  }, {
    key: "addMaterialToCache",
    value: function addMaterialToCache(materialCache) {
      this._materialCache.push(materialCache);
    }
  }, {
    key: "updateModelIteration",
    value: function updateModelIteration() {
      this._modelIteration = this._modelIteration + 1;
    }
  }, {
    key: "init",
    value: function init(diva3durl, gameCanvas, viewpoint, resolution) {
      shadow();
      Tools.fallbackTexture = 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw=='; // blank white image
      this.setResolution(gameCanvas, resolution);
      var cams = createCams(this._scene, viewpoint);
      this._targetCameraPosition = cams[0].position;
      lightning(diva3durl, this._scene, cams, this._utilStore.isMobile, this);
    }
  }, {
    key: "setRoot",
    value: function setRoot(bbn, hqs) {
      this._sceneConstruct.root = {
        bbn: bbn,
        hqs: hqs,
        sets: []
      };
    }
  }, {
    key: "addSet",
    value: function addSet(bbn, hqs) {
      if (!this._sceneConstruct.root) {
        throw new Error("can't register sets before root");
      }
      this._sceneConstruct.root.sets.push({
        bbn: bbn,
        hqs: hqs,
        elements: []
      });
    }
  }, {
    key: "addElement",
    value: function addElement(bbn, hqs) {
      var _this$_sceneConstruct8;
      var set = (_this$_sceneConstruct8 = this._sceneConstruct.root) === null || _this$_sceneConstruct8 === void 0 ? void 0 : _this$_sceneConstruct8.sets[this._sceneConstruct.root.sets.length - 1];
      if (!set) {
        throw new Error("can't register sets before root");
      }
      set.elements.filter(function (el) {
        return el.hqs.name == hqs.name;
      }).length == 0 && set.elements.push({
        bbn: bbn,
        hqs: hqs,
        geos: []
      });
    }
  }, {
    key: "removeElement",
    value: function removeElement(hqs) {
      var _this$_sceneConstruct9;
      var set = (_this$_sceneConstruct9 = this._sceneConstruct.root) === null || _this$_sceneConstruct9 === void 0 ? void 0 : _this$_sceneConstruct9.sets[this._sceneConstruct.root.sets.length - 1];
      if (!set) {
        throw new Error("can't register sets before root");
      }
      set.elements = set.elements.filter(function (el) {
        return el.hqs.name != hqs.name;
      });
    }
  }, {
    key: "shouldExport",
    value: function shouldExport(node) {
      if (node.name == 'Root') return true;
      if (!node.parent) return false;
      return this.shouldExport(node.parent);
    }
  }, {
    key: "onMissingGeo",
    value: function onMissingGeo() {
      var _this$_onMissingGeo;
      getLogger('ARViewer', 'RealTimeRenderData').error(new DivaError('Missing Geo in HQR ', {
        custom: {
          hqr: this._hqRenderScript
        }
      }));
      (_this$_onMissingGeo = this._onMissingGeo) === null || _this$_onMissingGeo === void 0 || _this$_onMissingGeo.call(this);
      this._cancelSceneExport = true;
    }
  }, {
    key: "exportScene",
    value: function () {
      var _exportScene = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var res;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (!this._cancelSceneExport) {
                _context.next = 2;
                break;
              }
              return _context.abrupt("return", new Promise(function () {
                return undefined;
              }));
            case 2:
              _context.next = 4;
              return GLTF2Export.GLBAsync(this._scene, 'fileName', {
                shouldExportNode: this.shouldExport.bind(this),
                exportUnusedUVs: false,
                exportWithoutWaitingForScene: false,
                removeNoopRootNodes: false,
                shouldExportAnimation: function shouldExportAnimation() {
                  return false;
                },
                metadataSelector: function metadataSelector() {
                  return false;
                }
              });
            case 4:
              res = _context.sent;
              return _context.abrupt("return", res);
            case 6:
            case "end":
              return _context.stop();
          }
        }, _callee, this);
      }));
      function exportScene() {
        return _exportScene.apply(this, arguments);
      }
      return exportScene;
    }()
  }, {
    key: "optimizeScene",
    value: function optimizeScene() {
      this._optimizer.start();
    }
  }, {
    key: "setCameraTarget",
    value: function setCameraTarget() {
      var root = this.scene.transformNodes.find(function (transformNode) {
        return transformNode.name == 'Root';
      });
      if (!root) return;
      var bbox = root.getHierarchyBoundingVectors();
      if (root.getChildren()[0].getChildren()[0].getChildren().length == 0) return; // planning is empty
      var pos = new Vector3((bbox.max.x + bbox.min.x) / 2, (bbox.max.y + bbox.min.y) / 2, (bbox.max.z + bbox.min.z) / 2);
      this.scene.getCameraByName('defaultCam').target = pos;
      this.cameraTargetPosition = pos;
    }
  }, {
    key: "getId",
    value: function getId(ob) {
      var id = ob.name;
      while (ob.parent) {
        id += '.' + ob.name;
        ob = ob.parent;
      }
      return id;
    }
  }, {
    key: "focusElement",
    value: function focusElement(root) {
      if (!root) root = this.scene.transformNodes.find(function (transformNode) {
        return transformNode.name == 'Root';
      });
      if (!root) return;
      var engine = this.scene.getEngine();
      var cam = this.scene.activeCamera;
      var bbox = root.getHierarchyBoundingVectors();
      var center = Vector3.Center(bbox.min, bbox.max);
      var radius = Vector3.Distance(bbox.min, bbox.max) / 2;
      if (radius == Infinity) return;
      var aspectRatio = engine.getRenderHeight() / engine.getRenderWidth();
      var distance = radius / Math.tan(cam.fov);
      var direction = cam.getDirection(Vector3.Backward());
      if (aspectRatio > 1) distance *= aspectRatio;
      var newPosition = center.add(direction.scale(distance * 1.7));
      if (newPosition.x == 0 && newPosition.y == 0 && newPosition.z == 0) return;
      this.cameraTargetPosition = center;
      this.targetCameraPosition = newPosition;
      this.runRenderLoopIndefinitely(); // runs till the updated unity images
      this.doRenderControlLoop = true;
      this._isControlledViewpoint = true;
      this._focusedElement = {
        id: this.getId(root),
        name: root.id,
        position: root.absolutePosition,
        size: Vector3.Distance(bbox.min, bbox.max)
      };
    }
  }, {
    key: "getMaxCamPosition",
    value: function getMaxCamPosition() {
      var root = this.scene.getTransformNodeByName('Root');
      if (!root) return Vector3.Zero();
      var _root$getHierarchyBou = root.getHierarchyBoundingVectors(true),
        min = _root$getHierarchyBou.min,
        max = _root$getHierarchyBou.max;
      return new Vector3(max.x - min.x, max.y - min.y, max.z - min.z);
    }
  }]);
}();

var delButton = "data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20height%3D%2224%22%20viewBox%3D%220%20-960%20960%20960%22%20width%3D%2224%22%3E%3Cpath%20d%3D%22M312-172q-25%200-42.5-17.5T252-232v-488h-40v-28h148v-28h240v28h148v28h-40v488q0%2026-17%2043t-43%2017H312Zm368-548H280v488q0%2014%209%2023t23%209h336q12%200%2022-10t10-22v-488ZM402-280h28v-360h-28v360Zm128%200h28v-360h-28v360ZM280-720v520-520Z%22%2F%3E%3C%2Fsvg%3E";

var gdelButton = "data:image/svg+xml,%3Csvg%20width%3D%2216%22%20height%3D%2221%22%20viewBox%3D%220%200%2016%2021%22%20fill%3D%22none%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22M15.2784%203.0226H10.9717V2.08029C10.9717%201.35784%2010.4151%200.72963%209.71198%200.72963H6.78229C6.10846%200.72963%205.52252%201.32643%205.52252%202.08029V3.0226H1.21588C0.981506%203.0226%200.776428%203.24248%200.776428%203.49376C0.776428%203.74505%200.981506%203.96492%201.21588%203.96492H2.18268V17.7542C2.18268%2019.0734%203.17877%2020.11%204.37994%2020.11H12.1436C13.3741%2020.11%2014.3409%2019.042%2014.3409%2017.7542V3.93351H15.3077C15.5714%203.93351%2015.7764%203.71364%2015.7764%203.46235C15.7764%203.17966%2015.5421%203.0226%2015.2784%203.0226ZM6.43073%202.08029C6.43073%201.829%206.6358%201.67195%206.78229%201.67195H9.71198C9.94635%201.67195%2010.0928%201.86041%2010.0928%202.08029V3.0226H6.43073V2.08029ZM13.462%2017.7228C13.462%2018.508%2012.876%2019.1363%2012.1436%2019.1363H4.37994C3.64752%2019.1363%203.06158%2018.508%203.06158%2017.7228V3.96492H13.462V17.7228Z%22%20fill%3D%22%234A4A4A%22%2F%3E%3Cpath%20d%3D%22M8.68658%206.82326V16.2464C8.68658%2016.5291%208.5108%2016.749%208.24713%2016.749C7.98346%2016.749%207.80768%2016.5291%207.80768%2016.2464V6.82326C7.80768%206.54056%208.04205%206.3521%208.24713%206.3521C8.48151%206.3521%208.68658%206.57197%208.68658%206.82326Z%22%20fill%3D%22%234A4A4A%22%2F%3E%3Cpath%20d%3D%22M11.6456%206.82326V16.2464C11.6456%2016.5291%2011.4405%2016.749%2011.2061%2016.749C10.9717%2016.749%2010.7667%2016.5291%2010.7667%2016.2464V6.82326C10.7667%206.54056%2010.9717%206.3521%2011.2061%206.3521C11.4405%206.3521%2011.6456%206.57197%2011.6456%206.82326Z%22%20fill%3D%22%234A4A4A%22%2F%3E%3Cpath%20d%3D%22M5.78619%206.82326V16.2464C5.78619%2016.5291%205.58112%2016.749%205.34674%2016.749C5.11237%2016.749%204.87799%2016.5291%204.87799%2016.2464V6.82326C4.87799%206.54056%205.08307%206.3521%205.31744%206.3521C5.55182%206.3521%205.78619%206.57197%205.78619%206.82326Z%22%20fill%3D%22%234A4A4A%22%2F%3E%3C%2Fsvg%3E";

function _createForOfIteratorHelper$6(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$6(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$6(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$6(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$6(r, a) : void 0; } }
function _arrayLikeToArray$6(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function SelHandler (_ref) {
  var onElSelected = _ref.onElSelected;
  var utilStore = useUtilStoreContext();
  var gridStore = useGridStoreContext();
  var sceneStore = useSceneStoreContext();
  var uiStore = useUIStoreContext();
  var timeoutId;
  var onSelection = function onSelection(evt) {
    if (evt.event.button == 2 || !(evt.type == 16 || evt.type == 64)) return;
    var ray = sceneStore.scene.createPickingRay(sceneStore.scene.pointerX, sceneStore.scene.pointerY, Matrix.Identity(), sceneStore.scene.activeCamera);
    var hit = sceneStore.scene.pickWithRay(ray);
    var pickedElement = false;
    var element = hit === null || hit === void 0 ? void 0 : hit.pickedMesh;
    clearTimeout(timeoutId);
    timeoutId = setTimeout(function () {
      var res = utilStore.findParentElementAndSet(element);
      if (res.element) {
        element = res.element;
        pickedElement = true;
        if (evt.type == 64 && hit !== null && hit !== void 0 && hit.pickedPoint) {
          onElementSelected(element, hit, true);
          return;
        } else if (evt.type == 16 && hit !== null && hit !== void 0 && hit.pickedPoint) {
          onElementSelected(element, hit);
          return;
        }
      }
      if (!pickedElement && hit !== null && hit !== void 0 && hit.pickedPoint) {
        var _hit$pickedMesh;
        if (sceneStore.elements) {
          var _iterator = _createForOfIteratorHelper$6(sceneStore.elements),
            _step;
          try {
            for (_iterator.s(); !(_step = _iterator.n()).done;) {
              var _element = _step.value;
              var _element$bbn$getHiera = _element.bbn.getHierarchyBoundingVectors(),
                min = _element$bbn$getHiera.min,
                max = _element$bbn$getHiera.max;
              var point = hit.pickedPoint;
              if (min.x < point.x && min.z < point.y && max.x > point.x && max.z > point.z && evt.type == 16) {
                pickedElement = true;
                onElementSelected(_element.bbn, hit);
              }
            }
          } catch (err) {
            _iterator.e(err);
          } finally {
            _iterator.f();
          }
        }
        if (!pickedElement && (hit === null || hit === void 0 || (_hit$pickedMesh = hit.pickedMesh) === null || _hit$pickedMesh === void 0 ? void 0 : _hit$pickedMesh.name) == 'ground' && sceneStore.sets && evt.type == 16) onSetSelected(sceneStore.sets[0].bbn);
      }
    }, 200);
  };
  var onSetSelected = function onSetSelected(elem) {
    gridStore.deselectGrids();
    sceneStore.focusElement(elem);
  };
  var onElementSelected = function onElementSelected(elem, hit, doubleClick) {
    var _sceneStore$focusedEl, _sceneStore$focusedEl2;
    var elemName = elem.name.slice(-1);
    var curElemName = (_sceneStore$focusedEl = sceneStore.focusedElement) === null || _sceneStore$focusedEl === void 0 || (_sceneStore$focusedEl = _sceneStore$focusedEl.name) === null || _sceneStore$focusedEl === void 0 || (_sceneStore$focusedEl2 = _sceneStore$focusedEl.slice) === null || _sceneStore$focusedEl2 === void 0 ? void 0 : _sceneStore$focusedEl2.call(_sceneStore$focusedEl, -1);
    if (doubleClick && curElemName == elemName && hit.pickedMesh) {
      var _getParent = function getParent(mesh) {
        var _mesh$parent;
        if (((_mesh$parent = mesh.parent) === null || _mesh$parent === void 0 ? void 0 : _mesh$parent.getClassName()) == 'TransformNode') return mesh.parent;
        return _getParent(mesh.parent);
      };
      sceneStore.focusElement(_getParent(hit.pickedMesh));
      return;
    } else if (curElemName != elemName && (doubleClick || curElemName == elemName)) {
      sceneStore.focusElement(elem);
    }
    uiStore.selectElem(elemName, elem, onElSelected);
  };
  return {
    onSelection: onSelection
  };
}

var arrowLeft = "data:image/svg+xml,%3Csvg%20width%3D%2214%22%20height%3D%2225%22%20fill%3D%22none%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22M1.477%2013.12c-.325-.33-.487-.496-.487-.7%200-.205.162-.37.487-.7L11.825%201.174C12.553.434%2012.917.063%2013.228.19c.311.127.311.647.311%201.686v21.088c0%201.04%200%201.559-.31%201.686-.312.127-.676-.244-1.404-.986L1.477%2013.12Z%22%20fill%3D%22%234A4A4A%22%20stroke%3D%22%23fff%22%20stroke-width%3D%220%2C5px%22%20stroke-linecap%3D%22round%22%2F%3E%3C%2Fsvg%3E";

function _createForOfIteratorHelper$5(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$5(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$5(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$5(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$5(r, a) : void 0; } }
function _arrayLikeToArray$5(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }

/* 
  UIStore
*/

var UIStore = /*#__PURE__*/function () {
  function UIStore(scene, enableSSAO, _utilStore, uiConfig, requestNewOverlayImage, _overlayImage, onElementCopy, runRenderLoopForTime, tabgroupTypeActive, isMobile) {
    var _this = this,
      _overlayImage$base;
    _classCallCheck(this, UIStore);
    _defineProperty(this, "_utilStore", void 0);
    _defineProperty(this, "_uiConfig", void 0);
    _defineProperty(this, "_gui", void 0);
    _defineProperty(this, "_requestNewOverlayImage", void 0);
    _defineProperty(this, "_onElementCopy", void 0);
    _defineProperty(this, "_timeoutId", void 0);
    _defineProperty(this, "_latestViewpoint", void 0);
    _defineProperty(this, "_guiElements", []);
    _defineProperty(this, "_scene", void 0);
    _defineProperty(this, "_enableSSAO", void 0);
    _defineProperty(this, "_selectionHandler", void 0);
    _defineProperty(this, "_colors", {
      defaultBg: 'rgba(240, 240, 240, 255)',
      selectedBg: 'rgba(100,0,0,255)',
      unselectableBg: '#dfdfdf',
      gridHoverBg: 'White',
      hoverBg: 'rgba(230, 230, 240, 255)'
    });
    _defineProperty(this, "_gridGui", void 0);
    _defineProperty(this, "_isStaticBg", void 0);
    _defineProperty(this, "_elementsInfo", void 0);
    _defineProperty(this, "_diffuseTexture", void 0);
    _defineProperty(this, "_plane", void 0);
    _defineProperty(this, "_shaderMat", void 0);
    _defineProperty(this, "_selectedMeshes", []);
    _defineProperty(this, "_isUnityComb", false);
    _defineProperty(this, "_selectedHl", void 0);
    _defineProperty(this, "_runRenderLoopForTime", void 0);
    _defineProperty(this, "_tabgroupTypeActive", void 0);
    _defineProperty(this, "_isMobile", void 0);
    _defineProperty(this, "_guiIsPicked", void 0);
    _defineProperty(this, "updateOverlayImage", function (overlayImage) {
      var _this$_diffuseTexture;
      if (!overlayImage || !_this._scene || ((_this$_diffuseTexture = _this._diffuseTexture) === null || _this$_diffuseTexture === void 0 ? void 0 : _this$_diffuseTexture.url) == overlayImage.base64) return;
      if (!_this._scene.activeCamera) createCams(_this._scene, undefined);
      var utilStore = useUtilStoreContext();
      if (!utilStore || !utilStore.updateCam) return;
      _this._isStaticBg = overlayImage.isStaticBg;
      if (_this._isStaticBg) {
        // no highlightlayer on static room bg
        _this.deactivateHighlightLayer();
        _this._plane.setEnabled(true);
      } else
        // never switch to rtv when in room
        _this._plane.setEnabled(false);
      _this.resize();
      _this._diffuseTexture.updateURL(overlayImage.base64, undefined, function () {
        return _this.fadeInOverlayImage(_this._plane.visibility == 1 || !!_this._isStaticBg);
      });
    });
    this._scene = scene;
    this._tabgroupTypeActive = tabgroupTypeActive;
    this._isMobile = !!isMobile;
    this._guiIsPicked = false;

    // Define shader
    Effect.ShadersStore["customVertexShader"] = "\n      precision highp float;\n\n      attribute vec3 position;\n      attribute vec2 uv;\n\n      uniform mat4 worldViewProjection;\n\n      varying vec2 vUV;\n\n      void main(void) {\n        gl_Position = worldViewProjection * vec4(position, 1.0);\n        vUV = uv;\n      }\n    ";
    Effect.ShadersStore["customFragmentShader"] = "\n      precision highp float;\n\n      varying vec2 vUV;\n\n      uniform sampler2D textureSampler;\n      uniform vec2 scale;\n      uniform float visibility;\n\n      void main(void) {\n        vec2 center = vec2(0.5, 0.5);\n        vec2 halfScale = scale * 0.5;\n        vec2 minUV = center - halfScale;\n        vec2 maxUV = center + halfScale;\n\n        // Always sample the texture\n        vec2 localUV = (vUV - minUV) / scale;\n        vec4 texColor = texture2D(textureSampler, localUV);\n\n        // Calculate mask: 1.0 inside, 0.0 outside\n        float inside = step(minUV.x, vUV.x) * step(vUV.x, maxUV.x)\n          * step(minUV.y, vUV.y) * step(vUV.y, maxUV.y);\n\n        // Mix texture and white\n        vec4 finalColor = mix(vec4(1.0), texColor, inside);\n        gl_FragColor = finalColor;\n        gl_FragColor.a *= visibility;\n      }\n    ";

    // Create material
    var shaderMat = new ShaderMaterial("shader", scene, {
      vertex: "custom",
      fragment: "custom"
    }, {
      attributes: ["position", "uv"],
      uniforms: ["worldViewProjection", "scale", "visibility"],
      samplers: ["textureSampler"]
    });
    this._diffuseTexture = new Texture((_overlayImage$base = _overlayImage === null || _overlayImage === void 0 ? void 0 : _overlayImage.base64) !== null && _overlayImage$base !== void 0 ? _overlayImage$base : 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8/wcAAwAB/ep3wWkAAAAASUVORK5CYII=', scene, false, true);
    shaderMat.setTexture("textureSampler", this._diffuseTexture);
    shaderMat.setVector2("scale", new Vector2(1, 1)); // adjust scale here
    shaderMat.alpha = 1;
    shaderMat.backFaceCulling = true;
    this._diffuseTexture.anisotropicFilteringLevel = 16;
    this._diffuseTexture.updateSamplingMode(Texture.TRILINEAR_SAMPLINGMODE);

    // Get aspect ratio of the current screen
    this._plane = MeshBuilder.CreatePlane('overlayplane', {
      size: 1
    }, scene);
    this._plane.visibility = 0;
    this._plane.setEnabled(false);
    this._plane.material = shaderMat;
    this._shaderMat = shaderMat;

    // Position it in front of the camera
    this._plane.position.z = 0.11;
    this._plane.isPickable = false;
    this._plane.parent = scene.activeCamera;
    this._selectedHl = new HighlightLayer('hl', this._scene);
    this._selectedHl.innerGlow = false;
    this._selectedHl.outerGlow = false;
    this._selectedHl.blurHorizontalSize = 1;
    this._selectedHl.blurVerticalSize = 1;
    this._selectedHl.mainTexture.samples = 4;
    this._enableSSAO = enableSSAO;
    this._utilStore = _utilStore;
    this._gui = AdvancedDynamicTexture.CreateFullscreenUI('UI');
    this._gui.layer.layerMask = 0x0fffffff;
    this._gui.renderScale = 1;
    this._requestNewOverlayImage = requestNewOverlayImage;
    this._onElementCopy = onElementCopy;
    this._uiConfig = uiConfig !== null && uiConfig !== void 0 ? uiConfig : {
      templateConfig: 'standard',
      posNumIcon: 'TOP_LEFT_BACK',
      posTrashIcon: 'POSNUM_TOP',
      hideUiIcons: false
    };
    if (this._uiConfig.templateConfig == 'gold') {
      this._colors.defaultBg = '#dfdfdf';
      this._colors.selectedBg = '#db3433';
    }
    this._isStaticBg = _overlayImage === null || _overlayImage === void 0 ? void 0 : _overlayImage.isStaticBg;
    if (_overlayImage) {
      this._plane.visibility = 1;
      this._isUnityComb = true;
      this._enableSSAO(false);
      if (_overlayImage.isStaticBg) this.fadeInOverlayImage(true);
    }
    this._runRenderLoopForTime = runRenderLoopForTime;
  }
  return _createClass(UIStore, [{
    key: "isStaticBg",
    get: function get() {
      return !!this._isStaticBg;
    }
  }, {
    key: "unityCombActive",
    get: function get() {
      return !!this._isUnityComb;
    }
  }, {
    key: "initSelectionHandler",
    value: function initSelectionHandler(onElementSelected) {
      var _this2 = this;
      this._selectionHandler = SelHandler({
        onElSelected: onElementSelected
      });
      this._scene.onPointerObservable.add(function (pointerInfo) {
        var _this2$_selectionHand;
        return !_this2._guiIsPicked && ((_this2$_selectionHand = _this2._selectionHandler) === null || _this2$_selectionHand === void 0 ? void 0 : _this2$_selectionHand.onSelection(pointerInfo));
      });
      this._scene.pointerMovePredicate = function (mesh) {
        return mesh.isPickable && mesh.isReady() && mesh.isEnabled() && (mesh.enablePointerMoveEvents || _this2._scene.constantlyUpdateMeshUnderPointer || mesh._getActionManagerForTrigger() !== null) && (!_this2._scene.cameraToUseForPointers || (_this2._scene.cameraToUseForPointers.layerMask & mesh.layerMask) !== 0);
      };
      this._scene.pointerDownPredicate = function (mesh) {
        return mesh.isPickable && mesh.isReady() && mesh.isEnabled() && (!_this2._scene.cameraToUseForPointers || (_this2._scene.cameraToUseForPointers.layerMask & mesh.layerMask) !== 0);
      };
      this._scene.pointerUpPredicate = function (mesh) {
        return mesh.isPickable && mesh.isReady() && mesh.isEnabled() && (!_this2._scene.cameraToUseForPointers || (_this2._scene.cameraToUseForPointers.layerMask & mesh.layerMask) !== 0);
      };
    }
  }, {
    key: "fadeOutOverlayImage",
    value: function fadeOutOverlayImage() {
      this._plane.visibility = 0;
      this._shaderMat.setFloat("visiblity", 0);
      var root = this._scene.getTransformNodeByName('Root');
      if (root) root.getChildMeshes().forEach(function (m) {
        m.visibility = 1;
        if (!m.material) return;
        m.material.depthFunction = Constants.LEQUAL;
        m.material.disableColorWrite = false;
      });
    }
  }, {
    key: "fadeInOverlayImage",
    value: function fadeInOverlayImage(skip) {
      var _this3 = this;
      var startTime = performance.now();
      this._plane.setEnabled(true);
      this._selectedHl.addExcludedMesh(this._plane);
      var _animate = function animate() {
        var elapsedTime = performance.now() - startTime;
        var progress = Math.min(elapsedTime / 500, 1); // Normalize progress (0 to 1)

        _this3._plane.visibility = skip ? 1 : progress;
        _this3._shaderMat.setFloat("visibility", skip ? 1 : progress);
        if (!skip && progress < 1) {
          requestAnimationFrame(_animate);
        } else {
          //animation finished
          _this3._enableSSAO(false);
          var size = _this3._diffuseTexture.getSize();
          var engine = _this3._scene.getEngine();
          var ratio = size.width / size.height;
          var engineRatio = engine.getRenderWidth() / engine.getRenderHeight();
          _this3._shaderMat.setVector2("scale", new Vector2(1 / (engineRatio / ratio), 1)); // adjust scale here */

          var root = _this3._scene.getTransformNodeByName('Root');
          if (root) root.getChildMeshes().forEach(function (m) {
            m.visibility = 0;
            if (!m.material) return;
            m.material.depthFunction = Constants.ALWAYS;
            m.material.disableColorWrite = true;
          });
          _this3._selectedMeshes.forEach(function (m) {
            return m.visibility = 1;
          });
        }
      };
      _animate();
    }
  }, {
    key: "createGridGui",
    value: function createGridGui(mesh, onClickDel) {
      var _this4 = this;
      if (!this._selectionHandler || !mesh || this._uiConfig.hideUiIcons) return;
      this.removeGridGui();
      var guiElem = new TransformNode('gridGuiElem', this._scene);
      var max = mesh.getHierarchyBoundingVectors().max;
      var min = mesh.getHierarchyBoundingVectors().min;
      guiElem.parent = mesh;
      var absolutePosition = new Vector3(min.x, max.y, max.z);
      var localPos = Vector3.TransformCoordinates(absolutePosition, guiElem.getWorldMatrix().invert());
      this._utilStore.moveObjectInDirection(guiElem, Vector3.Backward(), Math.abs(localPos.z));
      this._utilStore.moveObjectInDirection(guiElem, Vector3.Up(), -localPos.y + 0.05);
      if (!onClickDel) return;
      var dtarget = this._uiConfig.templateConfig == 'standard' ? new Ellipse('deleteEllipse') : new Rectangle('deleteEllipse');
      var size = this._uiConfig.templateConfig == 'standard' ? this._isMobile ? '28px' : '40px' : '35px';
      dtarget.width = size;
      dtarget.height = size;
      dtarget.thickness = 1;
      dtarget.background = this._colors.defaultBg;
      var dbt = Button.CreateImageOnlyButton('buttond', this._uiConfig.templateConfig == 'standard' ? delButton : gdelButton);
      dbt.color = 'transparent';
      var nSize = this._isMobile ? '28px' : '40px';
      dbt.width = this._uiConfig.templateConfig == 'standard' ? nSize : '60%';
      dbt.height = this._uiConfig.templateConfig == 'standard' ? nSize : '70%';
      dbt.onPointerClickObservable.add(onClickDel);
      dtarget.onPointerEnterObservable = new Observable(function () {
        return dtarget.background = _this4._colors.gridHoverBg;
      });
      dtarget.onPointerOutObservable = new Observable(function () {
        return dtarget.background = _this4._colors.defaultBg;
      });
      if (this._uiConfig.templateConfig == 'standard') dtarget.linkOffsetY = -48;
      dtarget.addControl(dbt);
      this._gui.addControl(dtarget);
      this._gridGui = {
        node: guiElem,
        gui: dtarget
      };
      dtarget.linkWithMesh(guiElem);
    }
  }, {
    key: "removeGridGui",
    value: function removeGridGui() {
      var _this$_gridGui, _this$_gridGui2;
      (_this$_gridGui = this._gridGui) === null || _this$_gridGui === void 0 || _this$_gridGui.gui.dispose();
      (_this$_gridGui2 = this._gridGui) === null || _this$_gridGui2 === void 0 || _this$_gridGui2.node.dispose();
    }
  }, {
    key: "resize",
    value: function resize() {
      if (!this._scene.activeCamera) return;
      // if rendering is cached it gets updated before resize is triggered, so check if the image is already correct
      var size = this._diffuseTexture.getSize();
      var engine = this._scene.getEngine();
      engine.resize();
      var ratio = size.width / size.height;
      var engineRatio = engine.getRenderWidth() / engine.getRenderHeight();
      this._shaderMat.setVector2("scale", new Vector2(1 / (engineRatio / ratio), 1)); // adjust scale here */
      this._gui.dispose();
      this._gui = AdvancedDynamicTexture.CreateFullscreenUI('UI', true, this._scene);
      this._gui.renderScale = 1;
      if (this._latestViewpoint) this._latestViewpoint.isOutdated = true;
      var aspectRatio = engine.getRenderWidth() / engine.getRenderHeight();
      var fov = this._scene.activeCamera.fov;
      var planeDepth = 0.11;
      // Calculate scaling factor based on frustum dimensions at the given depth
      var heightAtDepth = 2 * Math.tan(fov / 2) * planeDepth;
      var widthAtDepth = heightAtDepth * aspectRatio;
      this._plane.scaling = new Vector3(widthAtDepth, heightAtDepth, 1);
    }
  }, {
    key: "addElementsInfo",
    value: function addElementsInfo(elementsInfo) {
      this._elementsInfo = elementsInfo;
    }
  }, {
    key: "pointerOverElement",
    value: function pointerOverElement(element) {
      var _this$_runRenderLoopF,
        _this5 = this;
      this.unityCombActive && ((_this$_runRenderLoopF = this._runRenderLoopForTime) === null || _this$_runRenderLoopF === void 0 ? void 0 : _this$_runRenderLoopF.call(this, 1000));
      this._selectedHl.removeAllMeshes();
      this._selectedHl.addExcludedMesh(this._plane);
      if (this._plane.visibility == 1) this._selectedMeshes.forEach(function (_m) {
        return _m.visibility = 0;
      });
      element.getChildMeshes().forEach(function (_m) {
        _m.visibility = 1;
        _this5._selectedHl.addMesh(_m, Color3.Black());
      });
    }
  }, {
    key: "pointerOutElement",
    value: function pointerOutElement(element) {
      var _this$_runRenderLoopF2,
        _this6 = this;
      this.unityCombActive && ((_this$_runRenderLoopF2 = this._runRenderLoopForTime) === null || _this$_runRenderLoopF2 === void 0 ? void 0 : _this$_runRenderLoopF2.call(this, 1000));
      this._selectedHl.removeAllMeshes();
      this._selectedHl.addExcludedMesh(this._plane);
      if (this._plane.visibility == 1) element.getChildMeshes().forEach(function (_m) {
        return _m.visibility = 0;
      });
      this._selectedMeshes.forEach(function (_m) {
        _m.visibility = 1;
        _this6._selectedHl.addMesh(_m, Color3.Black());
      });
    }
  }, {
    key: "createPosNr",
    value: function createPosNr(elementInfo, element, isBoxPlanner, onElSelected) {
      var _this7 = this,
        _this$_elementsInfo,
        _this$_tabgroupTypeAc;
      var guiElem = {
        elementId: elementInfo.elementId,
        elements: []
      };
      var bbox = element.getHierarchyBoundingVectors();
      var guiElemLeftBack = null;
      var guiElemRightBack = null;
      if (!isBoxPlanner && elementInfo.selectable && this._uiConfig.templateConfig != 'hidden') {
        guiElemLeftBack = new TransformNode('guiElem_' + elementInfo.elementId, this._scene);
        var forward = element.getDirection(Vector3.Forward()).normalize();
        var left = element.getDirection(Vector3.Left()).normalize();
        var x = bbox.max.x;
        var z = bbox.min.z;
        if (forward.x < forward.z) x = bbox.min.x;
        if (left.z > left.x) z = bbox.max.z;
        guiElemLeftBack.position = new Vector3(x, bbox.max.y, z);
        guiElem.elements.push(guiElemLeftBack);
        guiElemRightBack = undefined;
        if (this._uiConfig.posTrashIcon == 'TOP_RIGHT_BACK' || isBoxPlanner) {
          guiElemRightBack = new TransformNode('guiElem_' + elementInfo.elementId, this._scene);
          var pos = new Vector3(bbox.min.x, bbox.max.y, bbox.min.z);
          guiElemRightBack.position = pos;
        }
        var target = this._uiConfig.templateConfig == 'standard' ? new Ellipse('posnrEllipse') : new Rectangle('posnrRectangle');
        if (this._uiConfig.templateConfig == 'gold') target.cornerRadius = 3;
        guiElem.elements.push(target);
        var size = this._uiConfig.templateConfig == 'standard' ? this._isMobile ? '28px' : '40px' : '20px';
        target.width = size;
        target.height = size;
        target.fontSize = this._uiConfig.templateConfig == 'standard' ? 50 : 20;
        target.background = this._colors.defaultBg;
        target.thickness = 0;
        if (elementInfo.active) {
          target.background = this._colors.selectedBg;
        } else {
          target.onPointerClickObservable.add(function (evt) {
            _this7._guiIsPicked = true;
            _this7.selectElem(element.name.slice(-1), element, onElSelected);
            setTimeout(function () {
              return _this7._guiIsPicked = false;
            }, 10);
          });
          target.onPointerEnterObservable.add(function () {
            return target.background = _this7._colors.hoverBg;
          });
          target.onPointerOutObservable.add(function () {
            target.background = _this7._colors.defaultBg;
          });
        }
        if (!elementInfo.selectable) target.background = '';
        this._gui.addControl(target);
        var label = new TextBlock('posnr_label');
        label.color = 'Black';
        label.fontFamily = 'Roboto';
        label.fontWeight = '100';
        if (elementInfo.active) label.color = 'White';
        if (!elementInfo.selectable) label.color = 'rgb(175, 172, 172)';
        label.text = elementInfo.posNr;
        guiElem.elements.push(label);
        target.addControl(label);
        target.linkWithMesh(guiElemLeftBack);
      } else {
        guiElemRightBack = new TransformNode('guiElem_' + elementInfo.elementId, this._scene);
        var _pos = new Vector3(bbox.min.x, bbox.max.y, bbox.min.z);
        guiElemRightBack.position = _pos;
      }
      var childMeshes = element.getChildMeshes();
      this._selectedHl.addExcludedMesh(this._plane);
      var cantSelect = (_this$_elementsInfo = this._elementsInfo) === null || _this$_elementsInfo === void 0 ? void 0 : _this$_elementsInfo.every(function (ei) {
        return ei.active;
      });
      childMeshes.forEach(function (m) {
        if (!m.material) return;
        if (_this7._plane.visibility == 1) {
          m.visibility = 0;
          m.material.depthFunction = Constants.ALWAYS;
          m.material.disableColorWrite = true;
        } else {
          m.visibility = 1;
          m.material.depthFunction = Constants.LEQUAL;
          m.material.disableColorWrite = false;
        }
        if (elementInfo.active) m.visibility = 1;
        if (!cantSelect && !elementInfo.active && elementInfo.selectable) {
          if (!m.actionManager) m.actionManager = new ActionManager(_this7._scene);
          m.actionManager.registerAction(new ExecuteCodeAction(ActionManager.OnPointerOverTrigger, function () {
            return _this7.pointerOverElement(element);
          }));
          m.actionManager.registerAction(new ExecuteCodeAction(ActionManager.OnPointerOutTrigger, function () {
            return _this7.pointerOutElement(element);
          }));
        } else if (!cantSelect && elementInfo.active) {
          var _m$actionManager;
          _this7._selectedMeshes = [].concat(_toConsumableArray(_this7._selectedMeshes), _toConsumableArray(childMeshes));
          _this7._selectedHl.addMesh(m, Color3.Black());
          (_m$actionManager = m.actionManager) === null || _m$actionManager === void 0 || _m$actionManager.dispose();
        } else {
          var _m$actionManager2;
          (_m$actionManager2 = m.actionManager) === null || _m$actionManager2 === void 0 || _m$actionManager2.dispose();
        }
      });
      if ((_this$_tabgroupTypeAc = this._tabgroupTypeActive) !== null && _this$_tabgroupTypeAc !== void 0 && _this$_tabgroupTypeAc.call(this, 'PLANNER') && elementInfo.active) {
        var _guiElemRightBack;
        var dtarget = this._uiConfig.templateConfig == 'standard' ? new Ellipse('deleteEllipse') : new Rectangle('deleteEllipse');
        guiElem.elements.push(dtarget);
        var _size = this._uiConfig.templateConfig == 'standard' ? this._isMobile ? '28px' : '40px' : '35px';
        dtarget.width = _size;
        dtarget.height = _size;
        dtarget.thickness = 1;
        dtarget.background = this._colors.defaultBg;
        var dbt = Button.CreateImageOnlyButton('buttond', this._uiConfig.templateConfig == 'standard' ? delButton : gdelButton);
        guiElem.elements.push(dbt);
        dbt.color = 'transparent';
        var nSize = this._isMobile ? '20px' : '40px';
        dbt.width = this._uiConfig.templateConfig == 'standard' ? nSize : '60%';
        dbt.height = this._uiConfig.templateConfig == 'standard' ? nSize : '70%';
        dbt.onPointerClickObservable.add(function () {
          return _this7._utilStore.onElementDeleted(elementInfo.setId, elementInfo.elementId);
        });
        if (this._uiConfig.templateConfig == 'standard' && !guiElemRightBack) dtarget.linkOffsetY = !this._isMobile ? -48 : -30;
        dtarget.addControl(dbt);
        this._gui.addControl(dtarget);
        dtarget.linkWithMesh((_guiElemRightBack = guiElemRightBack) !== null && _guiElemRightBack !== void 0 ? _guiElemRightBack : guiElemLeftBack);
      }
      this._guiElements.push(guiElem);
    }
  }, {
    key: "createBoxCopyButtons",
    value: function createBoxCopyButtons(elementInfo, element) {
      var _this$_scene$activeCa,
        _this$_scene$activeCa2,
        _this8 = this,
        _this$_scene$activeCa3;
      var guiElem = {
        elementId: elementInfo.elementId,
        elements: []
      };
      var bbox = element.getHierarchyBoundingVectors();
      var guiElement = new TransformNode('boxCopyButton', this._scene);
      guiElem.elements.push(guiElement);
      guiElement.billboardMode = Mesh.BILLBOARDMODE_ALL;
      var target = Button.CreateImageOnlyButton('but', arrowLeft);
      guiElem.elements.push(target);
      target.thickness = 0;
      target.width = '20px';
      target.height = '40px';
      var dir = (_this$_scene$activeCa = this._scene.activeCamera) === null || _this$_scene$activeCa === void 0 ? void 0 : _this$_scene$activeCa.getDirection(Axis.Z);
      switch (elementInfo.type) {
        case 'BoxCopyLeft':
          guiElement.position = element.absolutePosition.add(new Vector3(0, (bbox.max.y - bbox.min.y) / 2, bbox.max.z - bbox.min.z));
          target.name = 'copyleft';
          if (dir.z > 0) {
            target.rotation = 180 * Math.PI / 180;
          } else {
            target.rotation = 0;
          }
          (_this$_scene$activeCa2 = this._scene.activeCamera) === null || _this$_scene$activeCa2 === void 0 || _this$_scene$activeCa2.onViewMatrixChangedObservable.add(function () {
            var _this8$_scene$activeC;
            var _dir = (_this8$_scene$activeC = _this8._scene.activeCamera) === null || _this8$_scene$activeC === void 0 ? void 0 : _this8$_scene$activeC.getDirection(Axis.Z);
            if (_dir.z > 0) {
              target.rotation = 180 * Math.PI / 180;
            } else {
              target.rotation = 0;
            }
          });
          target.onPointerClickObservable.add(function () {
            var _this8$_onElementCopy;
            return (_this8$_onElementCopy = _this8._onElementCopy) === null || _this8$_onElementCopy === void 0 ? void 0 : _this8$_onElementCopy.call(_this8, elementInfo.setId, elementInfo.elementId, 'LEFT');
          });
          break;
        case 'BoxCopyRight':
          if (dir.z < 0) {
            target.rotation = 180 * Math.PI / 180;
          } else {
            target.rotation = 0;
          }
          target.name = 'copyright';
          guiElement.position = element.absolutePosition.add(new Vector3(-(bbox.max.x - bbox.min.x), (bbox.max.y - bbox.min.y) / 2, bbox.max.z - bbox.min.z));
          guiElement.rotation = new Vector3(90 * Math.PI / 180, 0, 0);
          (_this$_scene$activeCa3 = this._scene.activeCamera) === null || _this$_scene$activeCa3 === void 0 || _this$_scene$activeCa3.onViewMatrixChangedObservable.add(function () {
            var _this8$_scene$activeC2;
            var _dir = (_this8$_scene$activeC2 = _this8._scene.activeCamera) === null || _this8$_scene$activeC2 === void 0 ? void 0 : _this8$_scene$activeC2.getDirection(Axis.Z);
            if (_dir.z < 0) {
              target.rotation = 180 * Math.PI / 180;
            } else {
              target.rotation = 0;
            }
          });
          target.onPointerClickObservable.add(function () {
            var _this8$_onElementCopy2;
            return (_this8$_onElementCopy2 = _this8._onElementCopy) === null || _this8$_onElementCopy2 === void 0 ? void 0 : _this8$_onElementCopy2.call(_this8, elementInfo.setId, elementInfo.elementId, 'RIGHT');
          });
          break;
        case 'BoxCopyTop':
          target.rotation = 90 * Math.PI / 180;
          guiElement.position = element.absolutePosition.add(new Vector3(-(bbox.max.x - bbox.min.x) / 2, bbox.max.y - bbox.min.y, bbox.max.z - bbox.min.z));
          target.onPointerClickObservable.add(function () {
            var _this8$_onElementCopy3;
            return (_this8$_onElementCopy3 = _this8._onElementCopy) === null || _this8$_onElementCopy3 === void 0 ? void 0 : _this8$_onElementCopy3.call(_this8, elementInfo.setId, elementInfo.elementId, 'TOP');
          });
          break;
      }
      this._gui.addControl(target);
      target.linkWithMesh(guiElement);
      this._guiElements.push(guiElem);
    }
  }, {
    key: "initGui",
    value: function initGui(onElSelected, elements) {
      var _this9 = this;
      // elementinfo update before unity -- return and wait for after buildscene
      if (!this._selectionHandler) this.initSelectionHandler(onElSelected);
      if (!this._scene || !this._elementsInfo || this._elementsInfo.filter(function (e) {
        return !!e.posNr;
      }).length > elements.length) return;
      this.clearGui();
      if (this._plane.parent == null) this._plane.parent = this._scene.activeCamera;
      var isBoxPlanner = !this._elementsInfo.every(function (v) {
        return v.type == 'PosNr';
      });
      this._selectedHl.removeAllMeshes();
      this._selectedMeshes = [];
      this._elementsInfo.forEach(function (elementInfo) {
        var emnt = elements.find(function (el) {
          return Number(el.bbn.name.slice(el.bbn.name.lastIndexOf('E') + 1, el.bbn.name.length)) == elementInfo.elementId;
        });
        if (!emnt) return;
        var element = _this9._scene.getTransformNodeByName(emnt.bbn.name);
        if (!element || _this9._uiConfig.hideUiIcons) return;
        if (elementInfo.type == 'PosNr') _this9.createPosNr(elementInfo, element, isBoxPlanner, onElSelected);else _this9.createBoxCopyButtons(elementInfo, element);
      });
    }
  }, {
    key: "selectElem",
    value: function selectElem(name, element, onElSelected) {
      var _this$_elementsInfo2,
        _this10 = this;
      var elementInfo = (_this$_elementsInfo2 = this._elementsInfo) === null || _this$_elementsInfo2 === void 0 ? void 0 : _this$_elementsInfo2.find(function (ef) {
        return ef.elementId.toString() == name;
      });
      if (!(elementInfo !== null && elementInfo !== void 0 && elementInfo.selectable) || elementInfo.active) return;
      this._selectedMeshes = element.getChildMeshes();
      var _iterator = _createForOfIteratorHelper$5(this._gui.getControlsByType('ellipse')),
        _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var ellipse = _step.value;
          ellipse.background = this._colors.defaultBg;
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
      this._guiElements.forEach(function (guiElem) {
        return guiElem.elements.forEach(function (element) {
          if (element.typeName == 'label') element.color = 'Black';
          if (element.typeName == 'Ellipse') element.color = _this10._colors.defaultBg;
          if (guiElem.elementId.toString() == name) {
            if (element.typeName == 'label') element.color = _this10._colors.selectedBg;
            if (element.typeName == 'Ellipse') element.color = 'White';
          }
        });
      });
      onElSelected === null || onElSelected === void 0 || onElSelected(element.parent.name, Number(name));
    }
  }, {
    key: "deactivateHighlightLayer",
    value: function deactivateHighlightLayer() {
      this._selectedHl.outerGlow = false;
    }
  }, {
    key: "activateHighlightLayer",
    value: function activateHighlightLayer() {
      if (this._isStaticBg) return; // highlightlayer should never be active when we have a background room
      this._selectedHl.outerGlow = true;
    }
  }, {
    key: "clearGui",
    value: function clearGui() {
      this._guiElements.forEach(function (guiElem) {
        return guiElem.elements.forEach(function (elem) {
          return elem.dispose();
        });
      });
      this._guiElements.length = 0;
      this._scene.transformNodes.forEach(function (tN) {
        return tN.name.startsWith('guiElem_') && tN.dispose();
      });
    }
  }, {
    key: "onMove",
    value: function onMove() {
      if (!this._isUnityComb || this._isStaticBg) return;
      if (this._plane.visibility != 0) {
        this._enableSSAO(true);
        this.fadeOutOverlayImage();
      }
      this._utilStore.updateCam = false; // need to always update since can move again while image is waiting to be updated
    }
  }, {
    key: "requestNewOverlayImage",
    value: function requestNewOverlayImage(viewpoint, focusedElement, targetCameraPosition, updateCameraInformation) {
      var _this11 = this;
      //this._overlayImage exists only when unity combi is enabled
      if (!this._isUnityComb || this._isStaticBg) return;
      var elementId = undefined;
      var setId = undefined;
      var ob = this._scene.getTransformNodeByName(focusedElement.name);
      var _this$_utilStore$find = this._utilStore.findParentElementAndSet(ob),
        element = _this$_utilStore$find.element,
        set = _this$_utilStore$find.set;
      if (element) {
        elementId = Number(element.name.slice(element.name.lastIndexOf('E') + 1, element.name.length));
        setId = set === null || set === void 0 ? void 0 : set.replace('planning_', '');
      }
      clearTimeout(this._timeoutId);
      if (!this._latestViewpoint || this._latestViewpoint.isOutdated || Math.abs(this._latestViewpoint.pos.x - viewpoint.pos.x) > 0.05 || Math.abs(this._latestViewpoint.pos.y - viewpoint.pos.y) > 0.05 || Math.abs(this._latestViewpoint.pos.z - viewpoint.pos.z) > 0.05 || Math.abs(this._latestViewpoint.rot.x - viewpoint.rot.x) > 0.05 || Math.abs(this._latestViewpoint.rot.y - viewpoint.rot.y) > 0.05 || Math.abs(this._latestViewpoint.rot.z - viewpoint.rot.z) > 0.05) {
        this._timeoutId = setTimeout(function () {
          var _this11$_requestNewOv;
          _this11._latestViewpoint = viewpoint;
          _this11._utilStore.addOutstandingImageCount();
          _this11._utilStore.updateCam = true;
          updateCameraInformation === null || updateCameraInformation === void 0 || updateCameraInformation(viewpoint);
          (_this11$_requestNewOv = _this11._requestNewOverlayImage) === null || _this11$_requestNewOv === void 0 || _this11$_requestNewOv.call(_this11, viewpoint, {
            adjustZoomInUnity: false,
            onlyAdjustZoomBBChanged: false,
            rotationCenter: viewpoint.targetPos,
            elementId: elementId,
            setId: setId
          });
        }, 200);
      } else {
        this.fadeInOverlayImage(false);
      }
    }
  }]);
}();

/* 
  UtilStore
*/

var UtilStore = /*#__PURE__*/function () {
  function UtilStore(isMobile, viewHandler) {
    _classCallCheck(this, UtilStore);
    _defineProperty(this, "_isMobile", void 0);
    _defineProperty(this, "_rtvAnalyzeData", []);
    _defineProperty(this, "_outstandingImageCount", void 0);
    _defineProperty(this, "_updateCam", void 0);
    _defineProperty(this, "_viewHandler", void 0);
    _defineProperty(this, "calculateBBoxCenter", function (ob) {
      var boundingBox = ob.getHierarchyBoundingVectors();
      return new Vector3$1((boundingBox.max.x + boundingBox.min.x) / 2, (boundingBox.max.y + boundingBox.min.y) / 2, (boundingBox.max.z + boundingBox.min.z) / 2);
    });
    _defineProperty(this, "radiansToDegrees", function (vector) {
      return new Vector3$1(vector.x * 180 / Math.PI, vector.y * 180 / Math.PI, vector.z * 180 / Math.PI);
    });
    _defineProperty(this, "degreesToRadians", function (vector) {
      return new Vector3$1(vector.x / 180 * Math.PI, vector.y / 180 * Math.PI, vector.z / 180 * Math.PI);
    });
    _defineProperty(this, "vector3ToBVector3", function (vector) {
      return new Vector3$1(vector.x, vector.y, vector.z);
    });
    _defineProperty(this, "bvector3ToVector3", function (vector) {
      return {
        x: vector.x,
        y: vector.y,
        z: vector.z
      };
    });
    this._isMobile = !!isMobile;
    this._viewHandler = viewHandler;
    this._outstandingImageCount = 0;
    this._updateCam = true;
  }
  return _createClass(UtilStore, [{
    key: "isMobile",
    get: function get() {
      return this._isMobile;
    }
  }, {
    key: "viewHandler",
    get: function get() {
      return this._viewHandler;
    }
  }, {
    key: "curTabGroupKey",
    get: function get() {
      var _this$_viewHandler;
      return (_this$_viewHandler = this._viewHandler) === null || _this$_viewHandler === void 0 ? void 0 : _this$_viewHandler.tabGroupState.curTabGroup.key;
    }
  }, {
    key: "updateCam",
    get: function get() {
      return this._updateCam;
    },
    set: function set(doUpdateCam) {
      this._updateCam = doUpdateCam;
    }
  }, {
    key: "updateWithUnityData",
    get: function get() {
      return true;
    }
  }, {
    key: "onElementDeleted",
    value: function onElementDeleted(setId, elementId) {
      var _this$viewHandler;
      this.addOutstandingImageCount();
      (_this$viewHandler = this.viewHandler) === null || _this$viewHandler === void 0 || _this$viewHandler.viewPlannerHandler.onElementDeleted(setId, elementId);
      this._updateCam = true;
    }
  }, {
    key: "addOutstandingImageCount",
    value: function addOutstandingImageCount() {
      this._outstandingImageCount++;
    }
  }, {
    key: "subtractOutstandingImageCount",
    value: function subtractOutstandingImageCount() {
      if (this._outstandingImageCount == 0) return;
      this._outstandingImageCount--;
    }
  }, {
    key: "disableElementRows",
    value: function disableElementRows(element, cache) {
      var _this = this;
      var elementsToDisable = [];
      cache.forEach(function (val) {
        var _val$geo, _val$material;
        if ((_val$geo = val.geo) !== null && _val$geo !== void 0 && _val$geo.onElements.filter(function (el) {
          return el.name == element;
        })) elementsToDisable.push(val.geo.name);
        if ((_val$material = val.material) !== null && _val$material !== void 0 && (_val$material = _val$material.onElements) !== null && _val$material !== void 0 && _val$material.filter(function (el) {
          return el.name == element;
        })) elementsToDisable.push(val.material.name);
      });
      this._rtvAnalyzeData.forEach(function (dt) {
        if (dt.active && elementsToDisable.includes(dt.name)) _this.setAnalyzeDataRowStatus(dt.name, false);
      });
    }
  }, {
    key: "setAnalyzeDataRowStatus",
    value: function setAnalyzeDataRowStatus(name, status) {
      this._rtvAnalyzeData = this._rtvAnalyzeData.filter(function (dt) {
        if (dt.name == name) dt.active = status;
        return dt;
      });
    }
  }, {
    key: "setAnalyzeDataRow",
    value: function setAnalyzeDataRow(row) {
      this._rtvAnalyzeData.push(row);
    }
  }, {
    key: "setRTVAnalyzeData",
    value: function setRTVAnalyzeData() {
      var _this$_viewHandler2;
      if (!((_this$_viewHandler2 = this._viewHandler) !== null && _this$_viewHandler2 !== void 0 && _this$_viewHandler2.rtvAnalyzeData)) return;
      this._viewHandler.rtvAnalyzeData = this._rtvAnalyzeData;
    }
  }, {
    key: "getTexture",
    value: function getTexture(url) {
      var time = 0;
      return new Promise(function (resolve, reject) {
        var xhr = new WebRequest();
        xhr.open('GET', url);
        xhr.responseType = 'arraybuffer';
        xhr.addEventListener('loadend', function () {
          if (this.status >= 200 && this.status < 300) {
            resolve({
              res: xhr.response,
              downloadTime: time,
              status: 200
            });
          } else {
            reject({
              status: this.status,
              statusText: xhr.statusText
            });
          }
        });
        xhr.addEventListener('readystatechange', function () {
          if (this.readyState == 3) {
            time = Date.now();
          }
          if (this.readyState == 4 && this.status < 300 && this.status >= 200) {
            time = Date.now() - time;
          }
        });
        xhr.addEventListener('error', function () {
          reject({
            status: this.status,
            statusText: xhr.statusText
          });
        });
        xhr.send();
      });
    }
  }, {
    key: "getInfoJson",
    value: function getInfoJson(url) {
      return new Promise(function (resolve, reject) {
        var xhr = new WebRequest();
        xhr.open('GET', url);
        xhr.responseType = 'json';
        xhr.addEventListener('loadend', function () {
          if (this.status >= 200 && this.status < 300) {
            resolve({
              res: xhr.response,
              status: 200
            });
          } else {
            reject({
              status: this.status,
              statusText: xhr.statusText
            });
          }
        });
        xhr.addEventListener('error', function () {
          reject({
            status: this.status,
            statusText: xhr.statusText
          });
        });
        xhr.send();
      });
    }
  }, {
    key: "moveObjectInDirection",
    value: function moveObjectInDirection(mesh, direction, distance) {
      var rotationMatrix = Matrix$1.RotationYawPitchRoll(mesh.rotation.y, mesh.rotation.x, mesh.rotation.z);
      direction = Vector3$1.TransformCoordinates(direction, rotationMatrix);
      direction.normalize();
      mesh.position.addInPlace(direction.scale(distance));
    }
  }, {
    key: "findParentElementAndSet",
    value: function findParentElementAndSet(ob) {
      var element = undefined;
      var set = undefined;
      while (ob) {
        var name = ob.name.toLowerCase();
        if (name.startsWith('element')) {
          element = ob;
        } else if (name.startsWith('planning')) {
          set = name;
        }
        ob = ob.parent;
      }
      return {
        element: element,
        set: set
      };
    }
  }]);
}();

var _context;
var unregisterContext = function unregisterContext() {
  _context = undefined;
};
var registerContext = function registerContext(scene, hqRenderScript, apiConfig, jwt, viewHandler, onMissingGeo, requestNewOverlayImage, overlayImage, uiConfig, updateCameraInformation, isMobile) {
  var utilStore = new UtilStore(false, viewHandler);
  var sceneStore = new SceneStore(scene, hqRenderScript, utilStore, apiConfig, jwt, onMissingGeo, updateCameraInformation);
  var uiStore = new UIStore(scene, sceneStore.enableSSAO.bind(sceneStore), utilStore, uiConfig, requestNewOverlayImage, overlayImage, viewHandler === null || viewHandler === void 0 ? void 0 : viewHandler.viewPlannerHandler.onElementCopy, sceneStore.runRenderLoopForTime.bind(sceneStore), viewHandler === null || viewHandler === void 0 ? void 0 : viewHandler.tabgroupTypeActive, isMobile);
  return _context = {
    utilStore: utilStore,
    sceneStore: sceneStore,
    uiStore: uiStore,
    gridStore: new GridStore(sceneStore, uiStore, viewHandler)
  };
};
var useUIStoreContext = function useUIStoreContext() {
  var _context2;
  return (_context2 = _context) === null || _context2 === void 0 ? void 0 : _context2.uiStore;
};
var useSceneStoreContext = function useSceneStoreContext() {
  var _context3;
  return (_context3 = _context) === null || _context3 === void 0 ? void 0 : _context3.sceneStore;
};
var useGridStoreContext = function useGridStoreContext() {
  var _context4;
  return (_context4 = _context) === null || _context4 === void 0 ? void 0 : _context4.gridStore;
};
var useUtilStoreContext = function useUtilStoreContext() {
  var _context5;
  return (_context5 = _context) === null || _context5 === void 0 ? void 0 : _context5.utilStore;
};

function _createForOfIteratorHelper$4(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$4(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$4(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$4(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$4(r, a) : void 0; } }
function _arrayLikeToArray$4(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function caching () {
  var _useSceneStoreContext = useSceneStoreContext(),
    cache = _useSceneStoreContext.cache,
    hqRenderScript = _useSceneStoreContext.hqRenderScript,
    previousHQRenderScript = _useSceneStoreContext.previousHQRenderScript;
    _useSceneStoreContext.scene;
  var elements = undefined;
  var chaching = function chaching() {
    var _hqRenderScript$scene, _scene$nodes, _curElementRoot$nodes, _curElementRoot$nodes2, _prevElementRoot$node;
    //element meaning actual planning element not just any 3d one
    var curElementRoot = (_hqRenderScript$scene = hqRenderScript.scene.nodes) === null || _hqRenderScript$scene === void 0 || (_hqRenderScript$scene = _hqRenderScript$scene[0].nodes) === null || _hqRenderScript$scene === void 0 || (_hqRenderScript$scene = _hqRenderScript$scene[0].nodes) === null || _hqRenderScript$scene === void 0 ? void 0 : _hqRenderScript$scene[0];
    var prevElementRoot = (_scene$nodes = previousHQRenderScript.scene.nodes) === null || _scene$nodes === void 0 || (_scene$nodes = _scene$nodes[0].nodes) === null || _scene$nodes === void 0 || (_scene$nodes = _scene$nodes[0].nodes) === null || _scene$nodes === void 0 ? void 0 : _scene$nodes[0];
    var updatedElements = (_curElementRoot$nodes = curElementRoot === null || curElementRoot === void 0 || (_curElementRoot$nodes2 = curElementRoot.nodes) === null || _curElementRoot$nodes2 === void 0 ? void 0 : _curElementRoot$nodes2.filter(function (curElement) {
      if ((prevElementRoot === null || prevElementRoot === void 0 ? void 0 : prevElementRoot.nodes) === undefined) return true;
      var didChange = true;
      var _iterator = _createForOfIteratorHelper$4(prevElementRoot.nodes),
        _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var prevElement = _step.value;
          if (JSON.stringify(curElement) === JSON.stringify(prevElement)) {
            didChange = false;
            break;
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
      if (didChange) return true;
      return false;
    })) !== null && _curElementRoot$nodes !== void 0 ? _curElementRoot$nodes : [];

    //! if element did not change but referenced asset
    hqRenderScript.assets.geos.forEach(function (geo, idx) {
      var _assets$geos, _cache$idx;
      var prevGeo = (_assets$geos = previousHQRenderScript.assets.geos) === null || _assets$geos === void 0 ? void 0 : _assets$geos[idx];
      if (prevGeo && !(geo.id + geo.name === prevGeo.id + prevGeo.name) && cache !== null && cache !== void 0 && (_cache$idx = cache[idx]) !== null && _cache$idx !== void 0 && (_cache$idx = _cache$idx.geo) !== null && _cache$idx !== void 0 && _cache$idx.onElements) {
        var _cache$idx$geo;
        var _iterator2 = _createForOfIteratorHelper$4((_cache$idx$geo = cache[idx].geo) === null || _cache$idx$geo === void 0 ? void 0 : _cache$idx$geo.onElements),
          _step2;
        try {
          var _loop = function _loop() {
            var updatedElement = _step2.value;
            if (!updatedElements.find(function (element) {
              return element.name == updatedElement.name;
            })) {
              var _curElementRoot$nodes3;
              var getCurUpdatedElement = curElementRoot === null || curElementRoot === void 0 || (_curElementRoot$nodes3 = curElementRoot.nodes) === null || _curElementRoot$nodes3 === void 0 ? void 0 : _curElementRoot$nodes3.filter(function (element) {
                return element.name === updatedElement.name;
              });
              updatedElements.push.apply(updatedElements, _toConsumableArray(getCurUpdatedElement));
            }
          };
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            _loop();
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    });
    hqRenderScript.assets.mats.forEach(function (mat, idx) {
      var _assets$mats, _cache$idx2;
      var prevMat = (_assets$mats = previousHQRenderScript.assets.mats) === null || _assets$mats === void 0 ? void 0 : _assets$mats[idx];
      if (prevMat && !(mat.id + mat.name === prevMat.id + prevMat.name) && cache !== null && cache !== void 0 && (_cache$idx2 = cache[idx]) !== null && _cache$idx2 !== void 0 && (_cache$idx2 = _cache$idx2.material) !== null && _cache$idx2 !== void 0 && _cache$idx2.onElements) {
        var _cache$idx$material;
        var _iterator3 = _createForOfIteratorHelper$4((_cache$idx$material = cache[idx].material) === null || _cache$idx$material === void 0 ? void 0 : _cache$idx$material.onElements),
          _step3;
        try {
          var _loop2 = function _loop2() {
            var updatedElement = _step3.value;
            if (!updatedElements.find(function (element) {
              return element.name == updatedElement.name;
            })) {
              var _curElementRoot$nodes4;
              var getCurupdatedElement = curElementRoot === null || curElementRoot === void 0 || (_curElementRoot$nodes4 = curElementRoot.nodes) === null || _curElementRoot$nodes4 === void 0 ? void 0 : _curElementRoot$nodes4.filter(function (element) {
                return element.name === updatedElement.name;
              });
              updatedElements.push.apply(updatedElements, _toConsumableArray(getCurupdatedElement));
            }
          };
          for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
            _loop2();
          }
        } catch (err) {
          _iterator3.e(err);
        } finally {
          _iterator3.f();
        }
      }
    });
    return {
      parent: curElementRoot,
      updatedElements: updatedElements,
      deletedElements: prevElementRoot === null || prevElementRoot === void 0 || (_prevElementRoot$node = prevElementRoot.nodes) === null || _prevElementRoot$node === void 0 ? void 0 : _prevElementRoot$node.filter(function (prevElement) {
        if ((curElementRoot === null || curElementRoot === void 0 ? void 0 : curElementRoot.nodes) === undefined) return true;
        var wasDeleted = true;
        var _iterator4 = _createForOfIteratorHelper$4(curElementRoot.nodes),
          _step4;
        try {
          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
            var curElement = _step4.value;
            if (curElement.name === prevElement.name) {
              wasDeleted = false;
              break;
            }
          }
        } catch (err) {
          _iterator4.e(err);
        } finally {
          _iterator4.f();
        }
        if (wasDeleted) return true;
        return false;
      })
    };
  };
  if (JSON.stringify(hqRenderScript) === JSON.stringify(previousHQRenderScript)) {
    return false;
  }
  elements = chaching();
  return elements;
}

var LOG$1 = getLogger('RealTimeViewer', 'ar-viewer');
var customMat = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_customMat) {
    var setDataRow,
      sceneStore,
      url,
      doReCtrTex,
      _mat,
      res,
      parsedMat,
      found,
      mat,
      _args = arguments;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          setDataRow = _args.length > 1 && _args[1] !== undefined ? _args[1] : true;
          sceneStore = useSceneStoreContext();
          url = new URL(sceneStore.apiConfig.constructorService + '/material');
          url.searchParams.append('name', _customMat.fileName);
          url.searchParams.append('isStdMat', _customMat.isStdMat.toString());
          url.searchParams.append('blob', _customMat.blob);
          url.searchParams.append('isIDM3D', _customMat.isIDM3D.toString());
          url.searchParams.append('debug', JSON.stringify(!!sceneStore.apiConfig.useDebugUrl));
          if (_customMat.tiling) url.searchParams.append('tiling', JSON.stringify(_customMat.tiling));
          _context.prev = 9;
          // need to re construct the textures, due to data loss(tiling, mimetype, etc.) on glbasync export after parse/serialize of a mat
          // just triggers the right things for that to work, texture itself is cached so no real perf impact 
          doReCtrTex = function doReCtrTex(texture) {
            if (!texture) return texture;
            var reCtrTex = new Texture(texture.url, _customMat.scene);
            reCtrTex.uScale = texture.uScale;
            reCtrTex.vScale = texture.vScale;
            reCtrTex._mimeType = texture.url.endsWith('.jpg') ? 'image/jpeg' : 'image/png';
            return reCtrTex;
          };
          _context.next = 13;
          return fetch(url.toString(), {
            method: 'GET',
            headers: {
              Authorization: "Bearer ".concat(sceneStore.jwt)
            }
          });
        case 13:
          _mat = _context.sent;
          _context.next = 16;
          return _mat.json();
        case 16:
          res = _context.sent;
          parsedMat = PBRMetallicRoughnessMaterial.Parse(res, _customMat.scene, '');
          parsedMat.name = _customMat.name;
          parsedMat.baseTexture = doReCtrTex(parsedMat.baseTexture);
          parsedMat.metallicRoughnessTexture = doReCtrTex(parsedMat.metallicRoughnessTexture);
          parsedMat.normalTexture = doReCtrTex(parsedMat.normalTexture);
          found = !!parsedMat.baseTexture;
          if (!found) LOG$1.warn('MISSING_MATERIAL: could not get material ' + _customMat.name + ' for iln ' + _customMat.blob);
          if (setDataRow) useUtilStoreContext().setAnalyzeDataRow({
            type: 'MAT',
            found: found,
            active: true,
            name: _customMat.name,
            path: _customMat.blob,
            sizeMb: 0
          });
          return _context.abrupt("return", {
            mat: parsedMat,
            found: true
          });
        case 28:
          _context.prev = 28;
          _context.t0 = _context["catch"](9);
          if (setDataRow) useUtilStoreContext().setAnalyzeDataRow({
            type: 'MAT',
            found: false,
            active: true,
            name: _customMat.name,
            path: _customMat.blob,
            sizeMb: 0
          });
        case 31:
          mat = new PBRMetallicRoughnessMaterial(_customMat.name, _customMat.scene);
          return _context.abrupt("return", {
            mat: mat,
            found: true
          });
        case 33:
        case "end":
          return _context.stop();
      }
    }, _callee, null, [[9, 28]]);
  }));
  return function customMat(_x) {
    return _ref.apply(this, arguments);
  };
}();

function _createForOfIteratorHelper$3(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$3(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$3(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$3(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$3(r, a) : void 0; } }
function _arrayLikeToArray$3(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
getLogger('RealTimeViewer', 'FindAsset');
function findAssets(_x, _x2) {
  return _findAssets.apply(this, arguments);
}
function _findAssets() {
  _findAssets = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(assets, cache) {
    var sceneStore, stdMatPath, utilStore, newCache, cacheGroup, unifyAndSetStdMats, _unifyAndSetStdMats, importGeo, _importGeo, _iterator, _step, _loop, _ret, _iterator2, _step2, _loop2, nwCache;
    return _regeneratorRuntime.wrap(function _callee3$(_context5) {
      while (1) switch (_context5.prev = _context5.next) {
        case 0:
          _importGeo = function _importGeo3() {
            _importGeo = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(geo, path) {
              var geoCached, size, result, mesh, _sceneStore$onMissing;
              return _regeneratorRuntime.wrap(function _callee2$(_context2) {
                while (1) switch (_context2.prev = _context2.next) {
                  case 0:
                    //check if geo was already imported
                    geoCached = cacheGroup.getChildren().find(function (g) {
                      return g.name == geo.name;
                    });
                    if (!geoCached) {
                      _context2.next = 3;
                      break;
                    }
                    return _context2.abrupt("return", geoCached);
                  case 3:
                    size = 0;
                    _context2.prev = 4;
                    _context2.next = 7;
                    return SceneLoader.ImportMeshAsync(null, path, geo.name + '.glb', sceneStore.scene, function (progress) {
                      size = progress.total;
                    });
                  case 7:
                    result = _context2.sent;
                    utilStore.setAnalyzeDataRow({
                      name: geo.name,
                      path: path + '/AR/' + geo.name + '.glb',
                      sizeMb: size / 1000000,
                      type: 'GEO',
                      active: true,
                      found: true
                    });
                    mesh = result.meshes[0].getChildren()[0];
                    mesh.scaling = mesh.scaling.multiply(result.meshes[0].scaling);
                    mesh.rotation = mesh.rotation.add(result.meshes[0].rotation);
                    mesh.setEnabled(false);
                    mesh.parent = null;
                    result.meshes[0].dispose();
                    mesh.name = geo.name;
                    mesh.parent = cacheGroup;
                    return _context2.abrupt("return", mesh);
                  case 20:
                    _context2.prev = 20;
                    _context2.t0 = _context2["catch"](4);
                    (_sceneStore$onMissing = sceneStore.onMissingGeo) === null || _sceneStore$onMissing === void 0 || _sceneStore$onMissing.call(sceneStore);
                    utilStore.setAnalyzeDataRow({
                      name: geo.name,
                      path: path + '/' + geo.name + '.glb',
                      active: true,
                      type: 'GEO',
                      sizeMb: 0,
                      found: false
                    });
                    return _context2.abrupt("return", undefined);
                  case 25:
                  case "end":
                    return _context2.stop();
                }
              }, _callee2, null, [[4, 20]]);
            }));
            return _importGeo.apply(this, arguments);
          };
          importGeo = function _importGeo2(_x13, _x14) {
            return _importGeo.apply(this, arguments);
          };
          _unifyAndSetStdMats = function _unifyAndSetStdMats3() {
            _unifyAndSetStdMats = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(geo, iln) {
              var splittedName, oldMatId, path, name, mat, oldMat, _iterator3, _step3, mesh, _iterator4, _step4, child;
              return _regeneratorRuntime.wrap(function _callee$(_context) {
                while (1) switch (_context.prev = _context.next) {
                  case 0:
                    if (!geo.material) {
                      _context.next = 20;
                      break;
                    }
                    splittedName = geo.material.name.split('.');
                    oldMatId = geo.material.uniqueId;
                    splittedName[0] = splittedName[0].replaceAll(' ', '');
                    path = "".concat(stdMatPath, "_Standard/AR/").concat(splittedName[0], "/");
                    name = splittedName[0];
                    if (!name.includes('std_')) {
                      _context.next = 8;
                      break;
                    }
                    return _context.abrupt("return");
                  case 8:
                    name = 'std_' + name;
                    _context.next = 11;
                    return createOrGetMaterial(name, path, splittedName[0], true, true, false, undefined, true);
                  case 11:
                    mat = _context.sent;
                    if (!mat.found) utilStore.setAnalyzeDataRow({
                      type: 'TEX',
                      active: true,
                      found: false,
                      name: splittedName[0],
                      path: path,
                      sizeMb: 0,
                      geo: geo.name
                    });
                    geo.material = mat.mat;
                    oldMat = sceneStore.scene.getMaterialByUniqueID(oldMatId);
                    _iterator3 = _createForOfIteratorHelper$3(oldMat.getBindedMeshes());
                    try {
                      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
                        mesh = _step3.value;
                        mesh.material = geo.material;
                      }
                    } catch (err) {
                      _iterator3.e(err);
                    } finally {
                      _iterator3.f();
                    }
                    oldMat.dispose();
                    _context.next = 37;
                    break;
                  case 20:
                    _iterator4 = _createForOfIteratorHelper$3(geo.getChildMeshes());
                    _context.prev = 21;
                    _iterator4.s();
                  case 23:
                    if ((_step4 = _iterator4.n()).done) {
                      _context.next = 29;
                      break;
                    }
                    child = _step4.value;
                    _context.next = 27;
                    return unifyAndSetStdMats(child, iln);
                  case 27:
                    _context.next = 23;
                    break;
                  case 29:
                    _context.next = 34;
                    break;
                  case 31:
                    _context.prev = 31;
                    _context.t0 = _context["catch"](21);
                    _iterator4.e(_context.t0);
                  case 34:
                    _context.prev = 34;
                    _iterator4.f();
                    return _context.finish(34);
                  case 37:
                  case "end":
                    return _context.stop();
                }
              }, _callee, null, [[21, 31, 34, 37]]);
            }));
            return _unifyAndSetStdMats.apply(this, arguments);
          };
          unifyAndSetStdMats = function _unifyAndSetStdMats2(_x11, _x12) {
            return _unifyAndSetStdMats.apply(this, arguments);
          };
          sceneStore = useSceneStoreContext();
          stdMatPath = sceneStore.apiConfig.diva3darchive + '/DivaStandardMaterials/';
          utilStore = useUtilStoreContext();
          newCache = cache;
          cacheGroup = sceneStore.scene.getTransformNodeByName('Cache');
          if (!cacheGroup) cacheGroup = new TransformNode('Cache', sceneStore.scene);
          //TODO: tiling with Node Materials, multiple Textures

          //! clean std. materials from importing (.00x)
          _iterator = _createForOfIteratorHelper$3(assets.geos);
          _context5.prev = 11;
          _loop = /*#__PURE__*/_regeneratorRuntime.mark(function _loop() {
            var geo, path, idm_path, mesh, cachedGeo;
            return _regeneratorRuntime.wrap(function _loop$(_context3) {
              while (1) switch (_context3.prev = _context3.next) {
                case 0:
                  geo = _step.value;
                  path = sceneStore.apiConfig.diva3darchive + '/' + geo.blob + '/' + geo.catCodex + '/AR/';
                  if (geo.isIDM3D) {
                    idm_path = geo.name.split('.');
                    path = sceneStore.apiConfig.diva3darchive + '/IDM3D_ARCHIV/GEOMETRIES/' + idm_path[0] + '/' + idm_path[1] + '/';
                  }
                  //! check if cached
                  if (!cache.find(function (cachedElement) {
                    var _cachedElement$geo;
                    return (_cachedElement$geo = cachedElement.geo) === null || _cachedElement$geo === void 0 ? void 0 : _cachedElement$geo.geometry.name.endsWith(geo.name);
                  })) {
                    _context3.next = 5;
                    break;
                  }
                  return _context3.abrupt("return", 0);
                case 5:
                  _context3.next = 7;
                  return importGeo(geo, path);
                case 7:
                  mesh = _context3.sent;
                  if (mesh) {
                    _context3.next = 10;
                    break;
                  }
                  return _context3.abrupt("return", 0);
                case 10:
                  cachedGeo = newCache.find(function (g) {
                    return g.id == geo.id;
                  });
                  if (cachedGeo) cachedGeo.geo = {
                    geometry: mesh,
                    onElements: [],
                    name: geo.name
                  };else newCache.push({
                    id: geo.id,
                    geo: {
                      geometry: mesh,
                      onElements: [],
                      name: geo.name
                    }
                  });
                  mesh.receiveShadows = true;
                  _context3.next = 15;
                  return unifyAndSetStdMats(mesh, geo.blob);
                case 15:
                case "end":
                  return _context3.stop();
              }
            }, _loop);
          });
          _iterator.s();
        case 14:
          if ((_step = _iterator.n()).done) {
            _context5.next = 21;
            break;
          }
          return _context5.delegateYield(_loop(), "t0", 16);
        case 16:
          _ret = _context5.t0;
          if (!(_ret === 0)) {
            _context5.next = 19;
            break;
          }
          return _context5.abrupt("continue", 19);
        case 19:
          _context5.next = 14;
          break;
        case 21:
          _context5.next = 26;
          break;
        case 23:
          _context5.prev = 23;
          _context5.t1 = _context5["catch"](11);
          _iterator.e(_context5.t1);
        case 26:
          _context5.prev = 26;
          _iterator.f();
          return _context5.finish(26);
        case 29:
          // Und alle materialien erstellt
          _iterator2 = _createForOfIteratorHelper$3(assets.mats);
          _context5.prev = 30;
          _loop2 = /*#__PURE__*/_regeneratorRuntime.mark(function _loop2() {
            var mat, _nwCache$material;
            return _regeneratorRuntime.wrap(function _loop2$(_context4) {
              while (1) switch (_context4.prev = _context4.next) {
                case 0:
                  mat = _step2.value;
                  nwCache = newCache.find(function (cache) {
                    return cache.id == mat.id;
                  });
                  if (!nwCache) {
                    _context4.next = 13;
                    break;
                  }
                  if (!(((_nwCache$material = nwCache.material) === null || _nwCache$material === void 0 ? void 0 : _nwCache$material.name) == mat.name)) {
                    _context4.next = 5;
                    break;
                  }
                  return _context4.abrupt("return", 1);
                case 5:
                  _context4.next = 7;
                  return createOrGetMaterial(mat.id + '_' + mat.name, mat.blob, mat.name, true, false, !!mat.isIDM3D, {
                    tileU: mat.tileU,
                    tileV: mat.tileV
                  }, true);
                case 7:
                  _context4.t0 = _context4.sent.mat;
                  _context4.t1 = [];
                  _context4.t2 = mat.name;
                  nwCache.material = {
                    mat: _context4.t0,
                    isStdMat: false,
                    onElements: _context4.t1,
                    name: _context4.t2
                  };
                  _context4.next = 23;
                  break;
                case 13:
                  _context4.t3 = newCache;
                  _context4.t4 = mat.id;
                  _context4.next = 17;
                  return createOrGetMaterial(mat.id + '_' + mat.name, mat.blob, mat.name, true, false, !!mat.isIDM3D, {
                    tileU: mat.tileU,
                    tileV: mat.tileV
                  }, true);
                case 17:
                  _context4.t5 = _context4.sent.mat;
                  _context4.t6 = [];
                  _context4.t7 = mat.name;
                  _context4.t8 = {
                    mat: _context4.t5,
                    onElements: _context4.t6,
                    name: _context4.t7,
                    isStdMat: false
                  };
                  _context4.t9 = {
                    id: _context4.t4,
                    material: _context4.t8
                  };
                  _context4.t3.push.call(_context4.t3, _context4.t9);
                case 23:
                case "end":
                  return _context4.stop();
              }
            }, _loop2);
          });
          _iterator2.s();
        case 33:
          if ((_step2 = _iterator2.n()).done) {
            _context5.next = 39;
            break;
          }
          return _context5.delegateYield(_loop2(), "t2", 35);
        case 35:
          if (!_context5.t2) {
            _context5.next = 37;
            break;
          }
          return _context5.abrupt("continue", 37);
        case 37:
          _context5.next = 33;
          break;
        case 39:
          _context5.next = 44;
          break;
        case 41:
          _context5.prev = 41;
          _context5.t3 = _context5["catch"](30);
          _iterator2.e(_context5.t3);
        case 44:
          _context5.prev = 44;
          _iterator2.f();
          return _context5.finish(44);
        case 47:
          return _context5.abrupt("return", {
            cacheGroup: cacheGroup,
            newCache: newCache
          });
        case 48:
        case "end":
          return _context5.stop();
      }
    }, _callee3, null, [[11, 23, 26, 29], [30, 41, 44, 47]]);
  }));
  return _findAssets.apply(this, arguments);
}
function createOrGetMaterial(_x3, _x4, _x5, _x6, _x7, _x8, _x9, _x10) {
  return _createOrGetMaterial.apply(this, arguments);
}
function _createOrGetMaterial() {
  _createOrGetMaterial = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(name, blob, fileName, checkExisting, isStdMat, isIDM3D, tiling, setDataRow) {
    var sceneStore, uiStore, _iterator5, _step5, cachedMaterial, mat, material;
    return _regeneratorRuntime.wrap(function _callee4$(_context6) {
      while (1) switch (_context6.prev = _context6.next) {
        case 0:
          sceneStore = useSceneStoreContext();
          uiStore = useUIStoreContext();
          if (!checkExisting) {
            _context6.next = 21;
            break;
          }
          _iterator5 = _createForOfIteratorHelper$3(sceneStore.materialCache);
          _context6.prev = 4;
          _iterator5.s();
        case 6:
          if ((_step5 = _iterator5.n()).done) {
            _context6.next = 13;
            break;
          }
          cachedMaterial = _step5.value;
          if (!(name === cachedMaterial.mat.name)) {
            _context6.next = 11;
            break;
          }
          cachedMaterial.lastUsage = sceneStore.modelIteration;
          return _context6.abrupt("return", {
            mat: cachedMaterial.mat,
            found: true
          });
        case 11:
          _context6.next = 6;
          break;
        case 13:
          _context6.next = 18;
          break;
        case 15:
          _context6.prev = 15;
          _context6.t0 = _context6["catch"](4);
          _iterator5.e(_context6.t0);
        case 18:
          _context6.prev = 18;
          _iterator5.f();
          return _context6.finish(18);
        case 21:
          mat = {
            isStdMat: !!isStdMat,
            isIDM3D: isIDM3D,
            blob: blob,
            name: name,
            fileName: fileName,
            scene: sceneStore.scene,
            tiling: tiling
          };
          _context6.next = 24;
          return customMat(mat, setDataRow);
        case 24:
          material = _context6.sent;
          if (uiStore.unityCombActive) material.mat.disableColorWrite = true;
          sceneStore.addMaterialToCache({
            mat: material.mat,
            isStdMat: isStdMat,
            lastUsage: sceneStore.modelIteration
          });
          return _context6.abrupt("return", {
            mat: material.mat,
            found: material.found
          });
        case 28:
        case "end":
          return _context6.stop();
      }
    }, _callee4, null, [[4, 15, 18, 21]]);
  }));
  return _createOrGetMaterial.apply(this, arguments);
}

function _createForOfIteratorHelper$2(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$2(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$2(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$2(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$2(r, a) : void 0; } }
function _arrayLikeToArray$2(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var buildScene = function buildScene(_ref) {
  var _sceneStore$elements;
  var startNode = _ref.startNode,
    parentNode = _ref.parentNode,
    cache = _ref.cache,
    cachedAssets = _ref.cachedAssets;
  var sceneStore = useSceneStoreContext();
  var utilStore = useUtilStoreContext();
  var scene = sceneStore.scene;
  var hqsGeos = sceneStore.hqRenderScript.assets.geos;
  var curElement = (_sceneStore$elements = sceneStore.elements) === null || _sceneStore$elements === void 0 || (_sceneStore$elements = _sceneStore$elements[0]) === null || _sceneStore$elements === void 0 ? void 0 : _sceneStore$elements.hqs;
  function recursiveIteration(hqsNode, parentNode) {
    // clone object from cache to scene
    function cloneObject(curGeo, parentNode) {
      cache.getChildTransformNodes(true).forEach(function (mesh) {
        var hqsGeo = hqsGeos.find(function (hqsGeo) {
          return hqsGeo.id === curGeo.id;
        });
        var curMeshName = hqsGeo === null || hqsGeo === void 0 ? void 0 : hqsGeo.name;
        if (hqsGeo && curMeshName && mesh.name == curMeshName) {
          var _cachedAssets$find;
          (_cachedAssets$find = cachedAssets.find(function (asset) {
            return asset.id == curGeo.id;
          })) === null || _cachedAssets$find === void 0 || (_cachedAssets$find = _cachedAssets$find.geo) === null || _cachedAssets$find === void 0 || _cachedAssets$find.onElements.push(curElement); // TODO
          var geo = mesh.clone('geo_' + mesh.name, parentNode);
          geo.position = new Vector3(curGeo.pos.x / 100, curGeo.pos.y / 100, -curGeo.pos.z / 100);
          geo.rotation = utilStore.degreesToRadians(_objectSpread(_objectSpread({}, curGeo.rot), {}, {
            x: hqsGeo.isIDM3D ? 90 - curGeo.rot.x : curGeo.rot.x
          }));
          geo.setEnabled(true);
          utilStore.setAnalyzeDataRowStatus(curMeshName, true);
        }
      });
    }
    function findGeos(curGeo, parentNode) {
      //! Copy cached Object
      cloneObject(curGeo, parentNode);

      //! getNodes / getGeos
      if (curGeo.nodes !== undefined) {
        var _iterator = _createForOfIteratorHelper$2(curGeo.nodes),
          _step;
        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var _node = _step.value;
            recursiveIteration(_node);
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
      //! each geo
      if (curGeo.geos !== undefined) {
        var _iterator2 = _createForOfIteratorHelper$2(curGeo.geos),
          _step2;
        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var geo = _step2.value;
            findGeos(geo, parentNode);
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    }

    // fill onElement for caching and other for applying in findmaterials
    function findMats(curMat, parentNode) {
      var cachedElement = cachedAssets.find(function (assets) {
        return assets.id == curMat.id;
      });
      if (!(cachedElement !== null && cachedElement !== void 0 && cachedElement.material)) return;
      cachedElement.material.onElements.push(curElement);
      utilStore.setAnalyzeDataRowStatus(cachedElement.material.name, true);
      if (cachedElement.material.onNodes) {
        cachedElement.material.onNodes.push(curMat.onNode);
      } else {
        cachedElement.material.onNodes = [curMat.onNode];
      }
      if (cachedElement.material.parents) {
        var _cachedElement$materi;
        (_cachedElement$materi = cachedElement.material.parents) === null || _cachedElement$materi === void 0 || _cachedElement$materi.push(parentNode);
      } else {
        cachedElement.material.parents = [parentNode];
      }
    }
    var node = new TransformNode(hqsNode.name, scene);
    if (hqsNode.name == 'Root') {
      //for model viewer direction
      hqsNode.rot.y = 180;
      sceneStore.setRoot(node, hqsNode);
    }
    if ((parentNode === null || parentNode === void 0 ? void 0 : parentNode.name) == 'Wohnzimmer') sceneStore.addSet(node, hqsNode);
    if (node !== null && node !== void 0 && node.name.startsWith('Element')) {
      sceneStore.hasPlanned = true;
      sceneStore.addElement(node, hqsNode);
      curElement = hqsNode;
    }
    node.position = new Vector3(hqsNode.pos.x / 100, hqsNode.pos.y / 100, -hqsNode.pos.z / 100);
    node.rotation = utilStore.degreesToRadians(hqsNode.rot);
    if (parentNode !== undefined) {
      node.parent = parentNode;
    }

    //! each node
    if (hqsNode.nodes !== undefined) {
      var _iterator3 = _createForOfIteratorHelper$2(hqsNode.nodes),
        _step3;
      try {
        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
          var child = _step3.value;
          recursiveIteration(child, node);
        }
      } catch (err) {
        _iterator3.e(err);
      } finally {
        _iterator3.f();
      }
    }
    //! each material
    if (hqsNode.mats !== undefined) {
      var _iterator4 = _createForOfIteratorHelper$2(hqsNode.mats),
        _step4;
      try {
        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
          var mat = _step4.value;
          findMats(mat, node);
        }
      } catch (err) {
        _iterator4.e(err);
      } finally {
        _iterator4.f();
      }
    }
    //! each geo
    if (hqsNode.geos !== undefined) {
      var _iterator5 = _createForOfIteratorHelper$2(hqsNode.geos),
        _step5;
      try {
        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
          var geo = _step5.value;
          findGeos(geo, node);
        }
      } catch (err) {
        _iterator5.e(err);
      } finally {
        _iterator5.f();
      }
    }
  }
  recursiveIteration(startNode, parentNode);
  sceneStore.cache = cachedAssets;
};

function _createForOfIteratorHelper$1(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray$1(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray$1(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray$1(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray$1(r, a) : void 0; } }
function _arrayLikeToArray$1(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function findMaterials(cache) {
  //! parent = the parent from which on every child should receive the Material
  //! id = the id which points to the material that should be assigned
  var setMaterials = function setMaterials(onNode, mat) {
    if (onNode !== null && onNode !== void 0 && onNode._isMesh) onNode.material = mat;
    var _iterator = _createForOfIteratorHelper$1(onNode.getChildMeshes()),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var mesh = _step.value;
        mesh.material = mat;
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  };

  //! find On Node from json to scene and then call setMaterials to apply it to all Children
  var findOnNode = function findOnNode(mat, parent) {
    if (!mat.onNodes) return;
    var children = parent.getChildTransformNodes(false);
    var _iterator2 = _createForOfIteratorHelper$1(children),
      _step2;
    try {
      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
        var child = _step2.value;
        var _iterator3 = _createForOfIteratorHelper$1(mat.onNodes),
          _step3;
        try {
          for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
            var onNode = _step3.value;
            if (onNode == "" || onNode == "ALL") setMaterials(child, mat.mat);
            if (child.name.startsWith(onNode) || child.name.startsWith('geo_') && child.name.includes(onNode)) {
              setMaterials(child, mat.mat);
            }
          }
        } catch (err) {
          _iterator3.e(err);
        } finally {
          _iterator3.f();
        }
      }
    } catch (err) {
      _iterator2.e(err);
    } finally {
      _iterator2.f();
    }
  };
  var _iterator4 = _createForOfIteratorHelper$1(cache),
    _step4;
  try {
    for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
      var element = _step4.value;
      if (!element.material || !element.material.parents) continue;
      var _iterator5 = _createForOfIteratorHelper$1(element.material.parents),
        _step5;
      try {
        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
          var parent = _step5.value;
          findOnNode(element.material, parent);
        }
      } catch (err) {
        _iterator5.e(err);
      } finally {
        _iterator5.f();
      }
    }
  } catch (err) {
    _iterator4.e(err);
  } finally {
    _iterator4.f();
  }
  return findMaterials;
}

function _createForOfIteratorHelper(r, e) { var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (!t) { if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) { t && (r = t); var _n = 0, F = function F() {}; return { s: F, n: function n() { return _n >= r.length ? { done: !0 } : { done: !1, value: r[_n++] }; }, e: function e(r) { throw r; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var o, a = !0, u = !1; return { s: function s() { t = t.call(r); }, n: function n() { var r = t.next(); return a = r.done, r; }, e: function e(r) { u = !0, o = r; }, f: function f() { try { a || null == t["return"] || t["return"](); } finally { if (u) throw o; } } }; }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function deacCache(cache) {
  var _iterator = _createForOfIteratorHelper(cache.getChildTransformNodes(true)),
    _step;
  try {
    for (_iterator.s(); !(_step = _iterator.n()).done;) {
      var node = _step.value;
      node.setEnabled(false);
    }
  } catch (err) {
    _iterator.e(err);
  } finally {
    _iterator.f();
  }
  return deacCache;
}

//! sets element set
var parser = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    var _changedElements$upda;
    var sceneStore, hasRendered, hqRenderScript, scene, cache, changedElements, utilStore, _yield$findAssets, cacheGroup, newCache, _changedElements$upda2;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) switch (_context.prev = _context.next) {
        case 0:
          sceneStore = useSceneStoreContext();
          hasRendered = sceneStore.hasRendered, hqRenderScript = sceneStore.hqRenderScript, scene = sceneStore.scene, cache = sceneStore.cache, changedElements = sceneStore.changedElements;
          utilStore = useUtilStoreContext(); //disable elementrows from old cache
          changedElements === null || changedElements === void 0 || (_changedElements$upda = changedElements.updatedElements) === null || _changedElements$upda === void 0 || _changedElements$upda.forEach(function (el) {
            return utilStore.disableElementRows(el.name, cache);
          });
          _context.next = 6;
          return findAssets(hqRenderScript.assets, cache);
        case 6:
          _yield$findAssets = _context.sent;
          cacheGroup = _yield$findAssets.cacheGroup;
          newCache = _yield$findAssets.newCache;
          sceneStore.updateModelIteration();
          if (changedElements && changedElements.deletedElements && changedElements.deletedElements.length > 0) {
            changedElements.deletedElements.forEach(function (deletedElement) {
              var _scene$getTransformNo;
              (_scene$getTransformNo = scene.getTransformNodeByName(deletedElement.name)) === null || _scene$getTransformNo === void 0 || _scene$getTransformNo.dispose();
              sceneStore.removeElement(deletedElement);
            });
          }
          if (changedElements && changedElements.updatedElements && changedElements.updatedElements.length > 0) {
            (_changedElements$upda2 = changedElements.updatedElements) === null || _changedElements$upda2 === void 0 || _changedElements$upda2.forEach(function (updatedElement) {
              var _scene$getTransformNo2;
              var parent = scene.getTransformNodeByName(changedElements.parent.name);
              if (!parent) throw new Error('Parent for Element not found -> parent changed');
              (_scene$getTransformNo2 = scene.getTransformNodeByName(updatedElement.name)) === null || _scene$getTransformNo2 === void 0 || _scene$getTransformNo2.dispose();
              buildScene({
                startNode: updatedElement,
                cache: cacheGroup,
                cachedAssets: newCache,
                parentNode: parent
              });
              findMaterials(newCache);
            });
          } else if (!hasRendered) {
            buildScene({
              startNode: hqRenderScript.scene.nodes[0],
              cache: cacheGroup,
              cachedAssets: newCache
            });
            findMaterials(newCache);
          }
          utilStore.setRTVAnalyzeData();
          deacCache(cacheGroup);
          sceneStore.checkMaterialCache();
        case 15:
        case "end":
          return _context.stop();
      }
    }, _callee);
  }));
  return function parser() {
    return _ref.apply(this, arguments);
  };
}();

var LOG = getLogger('ARViewer', 'RealTimeRenderData');
function useRealTimeRenderData (_ref) {
  var _sceneStore2;
  var jwt = _ref.jwt,
    actions = _ref.actions,
    apiConfig = _ref.apiConfig,
    renderjob = _ref.renderjob,
    viewpoint = _ref.viewpoint,
    resolution = _ref.resolution,
    viewHandler = _ref.viewHandler,
    inBackground = _ref.inBackground,
    elementsInfo = _ref.elementsInfo,
    overlayImage = _ref.overlayImage,
    freePlacesOnGrids = _ref.freePlacesOnGrids,
    plannedPlacesOnGrids = _ref.plannedPlacesOnGrids,
    callbacks = _ref.callbacks,
    uiConfig = _ref.uiConfig,
    renderInBackground = _ref.renderInBackground,
    isMobile = _ref.isMobile;
  var gameCanvas = useRef(null);
  var sceneStore = useSceneStoreContext();
  var utilStore = useUtilStoreContext();
  var gridStore = useGridStoreContext();
  var uiStore = useUIStoreContext();
  DracoCompression.Configuration = {
    decoder: {
      wasmUrl: apiConfig.diva3darchive + '/draco/draco_decoder_gltf.js',
      wasmBinaryUrl: apiConfig.diva3darchive + '/draco/draco_decoder_gltf.wasm',
      fallbackUrl: apiConfig.diva3darchive + '/draco/draco_wasm_wrapper_gltf.js'
    }
  };
  var checkCachedData = function checkCachedData() {
    var elements = caching();
    if (!elements || (!elements.deletedElements || elements.deletedElements.length == 0) && (!elements.updatedElements || elements.updatedElements.length == 0)) {
      var _callbacks$onInitiali;
      if (!elementsInfo) return false;
      if (freePlacesOnGrids || plannedPlacesOnGrids) gridStore.getGrids(freePlacesOnGrids, plannedPlacesOnGrids);
      (_callbacks$onInitiali = callbacks.onInitialized) === null || _callbacks$onInitiali === void 0 || _callbacks$onInitiali.call(callbacks);
      sceneStore.isInitializing = false;
      return false;
    } else {
      sceneStore.changedElements = elements;
      return true;
    }
  };
  function onSceneReady() {
    return _onSceneReady.apply(this, arguments);
  }
  function _onSceneReady() {
    _onSceneReady = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            if (!sceneStore.isInitializing) {
              _context2.next = 2;
              break;
            }
            return _context2.abrupt("return");
          case 2:
            sceneStore.isInitializing = true;
            if (!overlayImage) actions.toggleLoading('buildScene', false, true);
            if (sceneStore.hasRendered) {
              _context2.next = 10;
              break;
            }
            if (inBackground) sceneStore.scene.getEngine().setHardwareScalingLevel(5);
            sceneStore.init(apiConfig.diva3darchive + '/', gameCanvas.current, viewpoint, resolution);
            uiStore.resize();
            _context2.next = 15;
            break;
          case 10:
            sceneStore.hqRenderScript = JSON.parse(renderjob);
            if (checkCachedData()) {
              _context2.next = 15;
              break;
            }
            if (!overlayImage) actions.toggleLoading('buildScene', false, false);
            sceneStore.isInitializing = false;
            return _context2.abrupt("return");
          case 15:
            LOG.startTransaction({
              event: 'buildScene',
              message: 'Start Building Realtime Scene',
              eventId: 'BUILD_SCENE'
            });
            _context2.prev = 16;
            uiStore.deactivateHighlightLayer();
            _context2.next = 20;
            return parser();
          case 20:
            uiStore.initGui(callbacks.onElementSelected, sceneStore.elements);
            if (freePlacesOnGrids || plannedPlacesOnGrids) gridStore.getGrids(freePlacesOnGrids, plannedPlacesOnGrids);
            _context2.next = 29;
            break;
          case 24:
            _context2.prev = 24;
            _context2.t0 = _context2["catch"](16);
            LOG.errorTransaction('BUILD_SCENE', 'RTS_0001', _context2.t0.message);
            LOG.error(new DivaError('Error building scene', {
              cause: _context2.t0,
              code: 'RTS_0001'
            }));
            sceneStore.isInitializing = false;
          case 29:
            if (callbacks.setGlb) {
              sceneStore.exportScene().then(function (res) {
                var _callbacks$setGlb;
                if (res) (_callbacks$setGlb = callbacks.setGlb) === null || _callbacks$setGlb === void 0 || _callbacks$setGlb.call(callbacks, URL.createObjectURL(res.glTFFiles['fileName.glb']), res.glTFFiles['fileName.glb']);
              });
            } else {
              LOG.debug('callbacks.setGlb is undefined');
            }
            if (!sceneStore.hasRendered) {
              sceneStore.hasRendered = true;
            }
            sceneStore.runRenderLoopIndefinitely();
            sceneStore.scene.onAfterRenderObservable.add(onFirstFrame);
            LOG.successTransaction('BUILD_SCENE');
          case 34:
          case "end":
            return _context2.stop();
        }
      }, _callee2, null, [[16, 24]]);
    }));
    return _onSceneReady.apply(this, arguments);
  }
  function onFirstFrame() {
    var _callbacks$onInitiali2;
    sceneStore.isInitializing = false;
    sceneStore.scene.onAfterRenderObservable.removeCallback(onFirstFrame);
    if (!overlayImage) actions.toggleLoading('buildScene', false, false);
    (_callbacks$onInitiali2 = callbacks.onInitialized) === null || _callbacks$onInitiali2 === void 0 || _callbacks$onInitiali2.call(callbacks);
    sceneStore.optimizeScene();
    setTimeout(function () {
      return uiStore.activateHighlightLayer();
    }, 500);
  }

  // trigger if gamecanvas did not update but renderjob
  if (gameCanvas.current && sceneStore && sceneStore.scene.getEngine()) {
    var _queueRerender = function queueRerender() {
      if (sceneStore.isInitializing) setTimeout(_queueRerender, 150);else {
        if (sceneStore.scene.isReady()) onSceneReady();else sceneStore.scene.executeWhenReady(function () {
          return onSceneReady();
        });
      }
    };
    _queueRerender();
  }
  useEffect(function () {
    var babylonScene = undefined;
    var babylonEngine = undefined;
    function init() {
      return _init.apply(this, arguments);
    }
    function _init() {
      _init = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        var context;
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) switch (_context.prev = _context.next) {
            case 0:
              if (gameCanvas.current) {
                _context.next = 2;
                break;
              }
              return _context.abrupt("return");
            case 2:
              _context.next = 4;
              return EngineFactory.CreateAsync(gameCanvas.current, {
                antialias: true,
                stencil: true,
                audioEngine: false,
                adaptToDeviceRatio: true
              });
            case 4:
              babylonEngine = _context.sent;
              babylonEngine.renderEvenInBackground = renderInBackground;
              babylonEngine.disablePerformanceMonitorInBackground = true;
              babylonScene = new Scene(babylonEngine, undefined);
              babylonScene.clearColor = new Color4(255, 255, 255, 255);
              context = registerContext(babylonScene, renderjob, apiConfig, jwt, viewHandler, callbacks.onMissingGeo, callbacks.requestNewOverlayImage, overlayImage, uiConfig, callbacks.updateCameraInformation, !!isMobile);
              sceneStore = context.sceneStore;
              utilStore = context.utilStore;
              gridStore = context.gridStore;
              uiStore = context.uiStore;
              if (!babylonScene.isReady()) {
                _context.next = 19;
                break;
              }
              _context.next = 17;
              return onSceneReady();
            case 17:
              _context.next = 20;
              break;
            case 19:
              babylonScene.executeWhenReady(function () {
                return onSceneReady();
              });
            case 20:
              if (window && gameCanvas.current) {
                window.addEventListener('resize', resize);
                new ResizeObserver(resize).observe(gameCanvas.current);
              }
            case 21:
            case "end":
              return _context.stop();
          }
        }, _callee);
      }));
      return _init.apply(this, arguments);
    }
    var resize = function resize() {
      var _sceneStore;
      if (inBackground || !((_sceneStore = sceneStore) !== null && _sceneStore !== void 0 && _sceneStore.scene) || !sceneStore.scene.getEngine() || !sceneStore.scene.isReady()) return;
      sceneStore.runRenderLoopIndefinitely();
      sceneStore.scene.getEngine().resize(true);
      uiStore.resize();
      uiStore.initGui(callbacks.onElementSelected, sceneStore.elements);
    };
    init();
    return function () {
      if (babylonEngine || babylonScene) {
        unregisterContext();
        sceneStore.scene.dispose();
        if (window) {
          window.removeEventListener('resize', resize);
        }
      }
    };
  }, []);
  useEffect(function () {
    if (overlayImage && uiStore && gameCanvas.current && sceneStore && sceneStore.scene.getEngine()) {
      if (!utilStore.updateCam) return;
      sceneStore.runRenderLoopForTime(1000);
      shadow(); // make sure the lighting is set up otherwise the image has a wrong color
      uiStore.updateOverlayImage(overlayImage);
      if (viewpoint) updateCam(viewpoint, sceneStore.scene);
    }
  }, [overlayImage]);
  useEffect(function () {
    if (sceneStore && elementsInfo && gameCanvas.current && sceneStore.scene.getEngine()) {
      uiStore.addElementsInfo(elementsInfo);
      uiStore.initGui(callbacks.onElementSelected, sceneStore.elements);
      sceneStore.runRenderLoopForTime(1000);
    }
  }, [elementsInfo, (_sceneStore2 = sceneStore) === null || _sceneStore2 === void 0 ? void 0 : _sceneStore2.elements]);
  useEffect(function () {
    if (!gameCanvas.current || !sceneStore) return;
    if (inBackground) {
      sceneStore.stopRenderLoop();
    } else if (sceneStore.hasRendered) {
      sceneStore.runRenderLoopIndefinitely();
    }
  }, [inBackground]);
  return {
    gameCanvas: gameCanvas
  };
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var canvas = "canvas-gZFEa";
var css_248z = ".canvas-gZFEa.focus-visible-ubYpO {\n  outline: medium none invert;\n  outline: initial;\n}\n\n.canvas-gZFEa.focus-visible-ubYpO {\n  outline: medium none invert;\n  outline: initial;\n}\n\n.canvas-gZFEa.focus-visible-ubYpO {\n  outline: medium none invert;\n  outline: initial;\n}\n\n.canvas-gZFEa:focus-visible {\n  outline: medium none invert;\n  outline: initial;\n}\n\n.flex-container-column-XYHvU {\n  display: flex;\n  flex-wrap: nowrap;\n  flex-direction: column;\n  background-color: white;\n  gap: 15px;\n  padding: 10px;\n  margin-top: 50px;\n  border: 0.5px solid;\n  border-top-right-radius: 10px;\n  border-bottom-right-radius: 10px;\n}\n\n.flex-container-column-closed-2D7IF {\n  display: flex;\n  flex-wrap: nowrap;\n  flex-direction: column;\n  background-color: white;\n  gap: 15px;\n  padding: 10px;\n}\n\n.flex-container-row-ENPOV {\n  display: flex;\n  justify-content: space-between;\n  flex-wrap: nowrap;\n  flex-direction: row;\n  background-color: white;\n  gap: 5px;\n}\n\n.create-button-NPGTz {\n  width: 200px;\n  height: 35px;\n  border-radius: 5px;\n  border-style: none;\n  color: #fff;\n  background-color: #713434;\n}\n\n.create-button-NPGTz:hover {\n  background-color: #42090e;\n}\n\n.check-box-2GPp1 {\n  width: 20px;\n  height: 20px;\n  margin: 0px;\n}\n\n.input-field-uCQ0h {\n  width: 193px;\n  height: 35px;\n  border-radius: 5px;\n  border-style: none;\n  color: rgb(0, 0, 0);\n  border-style: solid;\n  border-color: #000000;\n  background-color: #f7f7f7;\n  border-width: 0.5px;\n}\n\n.input-field-uCQ0h:hover {\n  background-color: #ebebeb;\n}\n";
styleInject(css_248z);

var RealTimeRenderer = /*#__PURE__*/memo(function (props) {
  var _useRealTimeRenderDat = useRealTimeRenderData(props),
    gameCanvas = _useRealTimeRenderDat.gameCanvas;
  return /*#__PURE__*/jsx("div", {
    style: {
      position: 'absolute',
      top: '0px',
      width: '100%',
      height: '100%',
      backgroundColor: 'white',
      zIndex: 2
    },
    children: /*#__PURE__*/jsx("canvas", {
      id: "gameCanvas",
      ref: gameCanvas,
      style: {
        height: '100%',
        width: '100%',
        margin: 'auto',
        display: 'block',
        backgroundColor: 'white'
      },
      className: canvas
    })
  });
}, function (prevProps, curProps) {
  var _prevProps$overlayIma, _curProps$overlayImag, _prevProps$overlayIma2, _curProps$overlayImag2, _curProps$overlayImag3;
  if (((_prevProps$overlayIma = prevProps.overlayImage) === null || _prevProps$overlayIma === void 0 ? void 0 : _prevProps$overlayIma.base64) != ((_curProps$overlayImag = curProps.overlayImage) === null || _curProps$overlayImag === void 0 ? void 0 : _curProps$overlayImag.base64) || ((_prevProps$overlayIma2 = prevProps.overlayImage) === null || _prevProps$overlayIma2 === void 0 ? void 0 : _prevProps$overlayIma2.isStaticBg) != ((_curProps$overlayImag2 = curProps.overlayImage) === null || _curProps$overlayImag2 === void 0 ? void 0 : _curProps$overlayImag2.isStaticBg) || (_curProps$overlayImag3 = curProps.overlayImage) !== null && _curProps$overlayImag3 !== void 0 && _curProps$overlayImag3.isStart) return false;
  if (prevProps.renderjob != curProps.renderjob) return false;
  if (JSON.stringify(prevProps.elementsInfo) != JSON.stringify(curProps.elementsInfo)) return false;
  if (prevProps.inBackground != curProps.inBackground) return false;
  if (JSON.stringify(curProps.freePlacesOnGrids) != JSON.stringify(prevProps.freePlacesOnGrids) || JSON.stringify(curProps.plannedPlacesOnGrids) != JSON.stringify(prevProps.plannedPlacesOnGrids)) return false;
  return true;
});

export { RealTimeRenderer as default };
